/*
 * Copyright (c) 2020, Muntashir Al-Islam
 * Copyright (c) 2015, Jared Rummler
 * Copyright (c) 2015, Liu Dong
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the <organization> nor the
 *       names of its contributors may be used to endorse or promote products
 *       derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package net.dongliu.apk.parser.utils;

import android.util.SparseArray;

import androidx.annotation.NonNull;

/**
 * methods for load resources.
 *
 * @author dongliu
 */
public class ResourceLoader {

    @NonNull
    public static SparseArray<String> loadSystemAttrIds() {
        SparseArray<String> array = new SparseArray<>();
        array.put(16842752, "theme");
        array.put(16842753, "label");
        array.put(16842754, "icon");
        array.put(16842755, "name");
        array.put(16842756, "manageSpaceActivity");
        array.put(16842757, "allowClearUserData");
        array.put(16842758, "permission");
        array.put(16842759, "readPermission");
        array.put(16842760, "writePermission");
        array.put(16842761, "protectionLevel");
        array.put(16842762, "permissionGroup");
        array.put(16842763, "sharedUserId");
        array.put(16842764, "hasCode");
        array.put(16842765, "persistent");
        array.put(16842766, "enabled");
        array.put(16842767, "debuggable");
        array.put(16842768, "exported");
        array.put(16842769, "process");
        array.put(16842770, "taskAffinity");
        array.put(16842771, "multiprocess");
        array.put(16842772, "finishOnTaskLaunch");
        array.put(16842773, "clearTaskOnLaunch");
        array.put(16842774, "stateNotNeeded");
        array.put(16842775, "excludeFromRecents");
        array.put(16842776, "authorities");
        array.put(16842777, "syncable");
        array.put(16842778, "initOrder");
        array.put(16842779, "grantUriPermissions");
        array.put(16842780, "priority");
        array.put(16842781, "launchMode");
        array.put(16842782, "screenOrientation");
        array.put(16842783, "configChanges");
        array.put(16842784, "description");
        array.put(16842785, "targetPackage");
        array.put(16842786, "handleProfiling");
        array.put(16842787, "functionalTest");
        array.put(16842788, "value");
        array.put(16842789, "resource");
        array.put(16842790, "mimeType");
        array.put(16842791, "scheme");
        array.put(16842792, "host");
        array.put(16842793, "port");
        array.put(16842794, "path");
        array.put(16842795, "pathPrefix");
        array.put(16842796, "pathPattern");
        array.put(16842797, "action");
        array.put(16842798, "data");
        array.put(16842799, "targetClass");
        array.put(16842800, "colorForeground");
        array.put(16842801, "colorBackground");
        array.put(16842802, "backgroundDimAmount");
        array.put(16842803, "disabledAlpha");
        array.put(16842804, "textAppearance");
        array.put(16842805, "textAppearanceInverse");
        array.put(16842806, "textColorPrimary");
        array.put(16842807, "textColorPrimaryDisableOnly");
        array.put(16842808, "textColorSecondary");
        array.put(16842809, "textColorPrimaryInverse");
        array.put(16842810, "textColorSecondaryInverse");
        array.put(16842811, "textColorPrimaryNoDisable");
        array.put(16842812, "textColorSecondaryNoDisable");
        array.put(16842813, "textColorPrimaryInverseNoDisable");
        array.put(16842814, "textColorSecondaryInverseNoDisable");
        array.put(16842815, "textColorHintInverse");
        array.put(16842816, "textAppearanceLarge");
        array.put(16842817, "textAppearanceMedium");
        array.put(16842818, "textAppearanceSmall");
        array.put(16842819, "textAppearanceLargeInverse");
        array.put(16842820, "textAppearanceMediumInverse");
        array.put(16842821, "textAppearanceSmallInverse");
        array.put(16842822, "textCheckMark");
        array.put(16842823, "textCheckMarkInverse");
        array.put(16842824, "buttonStyle");
        array.put(16842825, "buttonStyleSmall");
        array.put(16842826, "buttonStyleInset");
        array.put(16842827, "buttonStyleToggle");
        array.put(16842828, "galleryItemBackground");
        array.put(16842829, "listPreferredItemHeight");
        array.put(16842830, "expandableListPreferredItemPaddingLeft");
        array.put(16842831, "expandableListPreferredChildPaddingLeft");
        array.put(16842832, "expandableListPreferredItemIndicatorLeft");
        array.put(16842833, "expandableListPreferredItemIndicatorRight");
        array.put(16842834, "expandableListPreferredChildIndicatorLeft");
        array.put(16842835, "expandableListPreferredChildIndicatorRight");
        array.put(16842836, "windowBackground");
        array.put(16842837, "windowFrame");
        array.put(16842838, "windowNoTitle");
        array.put(16842839, "windowIsFloating");
        array.put(16842840, "windowIsTranslucent");
        array.put(16842841, "windowContentOverlay");
        array.put(16842842, "windowTitleSize");
        array.put(16842843, "windowTitleStyle");
        array.put(16842844, "windowTitleBackgroundStyle");
        array.put(16842845, "alertDialogStyle");
        array.put(16842846, "panelBackground");
        array.put(16842847, "panelFullBackground");
        array.put(16842848, "panelColorForeground");
        array.put(16842849, "panelColorBackground");
        array.put(16842850, "panelTextAppearance");
        array.put(16842851, "scrollbarSize");
        array.put(16842852, "scrollbarThumbHorizontal");
        array.put(16842853, "scrollbarThumbVertical");
        array.put(16842854, "scrollbarTrackHorizontal");
        array.put(16842855, "scrollbarTrackVertical");
        array.put(16842856, "scrollbarAlwaysDrawHorizontalTrack");
        array.put(16842857, "scrollbarAlwaysDrawVerticalTrack");
        array.put(16842858, "absListViewStyle");
        array.put(16842859, "autoCompleteTextViewStyle");
        array.put(16842860, "checkboxStyle");
        array.put(16842861, "dropDownListViewStyle");
        array.put(16842862, "editTextStyle");
        array.put(16842863, "expandableListViewStyle");
        array.put(16842864, "galleryStyle");
        array.put(16842865, "gridViewStyle");
        array.put(16842866, "imageButtonStyle");
        array.put(16842867, "imageWellStyle");
        array.put(16842868, "listViewStyle");
        array.put(16842869, "listViewWhiteStyle");
        array.put(16842870, "popupWindowStyle");
        array.put(16842871, "progressBarStyle");
        array.put(16842872, "progressBarStyleHorizontal");
        array.put(16842873, "progressBarStyleSmall");
        array.put(16842874, "progressBarStyleLarge");
        array.put(16842875, "seekBarStyle");
        array.put(16842876, "ratingBarStyle");
        array.put(16842877, "ratingBarStyleSmall");
        array.put(16842878, "radioButtonStyle");
        array.put(16842879, "scrollbarStyle");
        array.put(16842880, "scrollViewStyle");
        array.put(16842881, "spinnerStyle");
        array.put(16842882, "starStyle");
        array.put(16842883, "tabWidgetStyle");
        array.put(16842884, "textViewStyle");
        array.put(16842885, "webViewStyle");
        array.put(16842886, "dropDownItemStyle");
        array.put(16842887, "spinnerDropDownItemStyle");
        array.put(16842888, "dropDownHintAppearance");
        array.put(16842889, "spinnerItemStyle");
        array.put(16842890, "mapViewStyle");
        array.put(16842891, "preferenceScreenStyle");
        array.put(16842892, "preferenceCategoryStyle");
        array.put(16842893, "preferenceInformationStyle");
        array.put(16842894, "preferenceStyle");
        array.put(16842895, "checkBoxPreferenceStyle");
        array.put(16842896, "yesNoPreferenceStyle");
        array.put(16842897, "dialogPreferenceStyle");
        array.put(16842898, "editTextPreferenceStyle");
        array.put(16842899, "ringtonePreferenceStyle");
        array.put(16842900, "preferenceLayoutChild");
        array.put(16842901, "textSize");
        array.put(16842902, "typeface");
        array.put(16842903, "textStyle");
        array.put(16842904, "textColor");
        array.put(16842905, "textColorHighlight");
        array.put(16842906, "textColorHint");
        array.put(16842907, "textColorLink");
        array.put(16842908, "state_focused");
        array.put(16842909, "state_window_focused");
        array.put(16842910, "state_enabled");
        array.put(16842911, "state_checkable");
        array.put(16842912, "state_checked");
        array.put(16842913, "state_selected");
        array.put(16842914, "state_active");
        array.put(16842915, "state_single");
        array.put(16842916, "state_first");
        array.put(16842917, "state_middle");
        array.put(16842918, "state_last");
        array.put(16842919, "state_pressed");
        array.put(16842920, "state_expanded");
        array.put(16842921, "state_empty");
        array.put(16842922, "state_above_anchor");
        array.put(16842923, "ellipsize");
        array.put(16842924, "x");
        array.put(16842925, "y");
        array.put(16842926, "windowAnimationStyle");
        array.put(16842927, "gravity");
        array.put(16842928, "autoLink");
        array.put(16842929, "linksClickable");
        array.put(16842930, "entries");
        array.put(16842931, "layout_gravity");
        array.put(16842932, "windowEnterAnimation");
        array.put(16842933, "windowExitAnimation");
        array.put(16842934, "windowShowAnimation");
        array.put(16842935, "windowHideAnimation");
        array.put(16842936, "activityOpenEnterAnimation");
        array.put(16842937, "activityOpenExitAnimation");
        array.put(16842938, "activityCloseEnterAnimation");
        array.put(16842939, "activityCloseExitAnimation");
        array.put(16842940, "taskOpenEnterAnimation");
        array.put(16842941, "taskOpenExitAnimation");
        array.put(16842942, "taskCloseEnterAnimation");
        array.put(16842943, "taskCloseExitAnimation");
        array.put(16842944, "taskToFrontEnterAnimation");
        array.put(16842945, "taskToFrontExitAnimation");
        array.put(16842946, "taskToBackEnterAnimation");
        array.put(16842947, "taskToBackExitAnimation");
        array.put(16842948, "orientation");
        array.put(16842949, "keycode");
        array.put(16842950, "fullDark");
        array.put(16842951, "topDark");
        array.put(16842952, "centerDark");
        array.put(16842953, "bottomDark");
        array.put(16842954, "fullBright");
        array.put(16842955, "topBright");
        array.put(16842956, "centerBright");
        array.put(16842957, "bottomBright");
        array.put(16842958, "bottomMedium");
        array.put(16842959, "centerMedium");
        array.put(16842960, "id");
        array.put(16842961, "tag");
        array.put(16842962, "scrollX");
        array.put(16842963, "scrollY");
        array.put(16842964, "background");
        array.put(16842965, "padding");
        array.put(16842966, "paddingLeft");
        array.put(16842967, "paddingTop");
        array.put(16842968, "paddingRight");
        array.put(16842969, "paddingBottom");
        array.put(16842970, "focusable");
        array.put(16842971, "focusableInTouchMode");
        array.put(16842972, "visibility");
        array.put(16842973, "fitsSystemWindows");
        array.put(16842974, "scrollbars");
        array.put(16842975, "fadingEdge");
        array.put(16842976, "fadingEdgeLength");
        array.put(16842977, "nextFocusLeft");
        array.put(16842978, "nextFocusRight");
        array.put(16842979, "nextFocusUp");
        array.put(16842980, "nextFocusDown");
        array.put(16842981, "clickable");
        array.put(16842982, "longClickable");
        array.put(16842983, "saveEnabled");
        array.put(16842984, "drawingCacheQuality");
        array.put(16842985, "duplicateParentState");
        array.put(16842986, "clipChildren");
        array.put(16842987, "clipToPadding");
        array.put(16842988, "layoutAnimation");
        array.put(16842989, "animationCache");
        array.put(16842990, "persistentDrawingCache");
        array.put(16842991, "alwaysDrawnWithCache");
        array.put(16842992, "addStatesFromChildren");
        array.put(16842993, "descendantFocusability");
        array.put(16842994, "layout");
        array.put(16842995, "inflatedId");
        array.put(16842996, "layout_width");
        array.put(16842997, "layout_height");
        array.put(16842998, "layout_margin");
        array.put(16842999, "layout_marginLeft");
        array.put(16843000, "layout_marginTop");
        array.put(16843001, "layout_marginRight");
        array.put(16843002, "layout_marginBottom");
        array.put(16843003, "listSelector");
        array.put(16843004, "drawSelectorOnTop");
        array.put(16843005, "stackFromBottom");
        array.put(16843006, "scrollingCache");
        array.put(16843007, "textFilterEnabled");
        array.put(16843008, "transcriptMode");
        array.put(16843009, "cacheColorHint");
        array.put(16843010, "dial");
        array.put(16843011, "hand_hour");
        array.put(16843012, "hand_minute");
        array.put(16843013, "format");
        array.put(16843014, "checked");
        array.put(16843015, "button");
        array.put(16843016, "checkMark");
        array.put(16843017, "foreground");
        array.put(16843018, "measureAllChildren");
        array.put(16843019, "groupIndicator");
        array.put(16843020, "childIndicator");
        array.put(16843021, "indicatorLeft");
        array.put(16843022, "indicatorRight");
        array.put(16843023, "childIndicatorLeft");
        array.put(16843024, "childIndicatorRight");
        array.put(16843025, "childDivider");
        array.put(16843026, "animationDuration");
        array.put(16843027, "spacing");
        array.put(16843028, "horizontalSpacing");
        array.put(16843029, "verticalSpacing");
        array.put(16843030, "stretchMode");
        array.put(16843031, "columnWidth");
        array.put(16843032, "numColumns");
        array.put(16843033, "src");
        array.put(16843034, "antialias");
        array.put(16843035, "filter");
        array.put(16843036, "dither");
        array.put(16843037, "scaleType");
        array.put(16843038, "adjustViewBounds");
        array.put(16843039, "maxWidth");
        array.put(16843040, "maxHeight");
        array.put(16843041, "tint");
        array.put(16843042, "baselineAlignBottom");
        array.put(16843043, "cropToPadding");
        array.put(16843044, "textOn");
        array.put(16843045, "textOff");
        array.put(16843046, "baselineAligned");
        array.put(16843047, "baselineAlignedChildIndex");
        array.put(16843048, "weightSum");
        array.put(16843049, "divider");
        array.put(16843050, "dividerHeight");
        array.put(16843051, "choiceMode");
        array.put(16843052, "itemTextAppearance");
        array.put(16843053, "horizontalDivider");
        array.put(16843054, "verticalDivider");
        array.put(16843055, "headerBackground");
        array.put(16843056, "itemBackground");
        array.put(16843057, "itemIconDisabledAlpha");
        array.put(16843058, "rowHeight");
        array.put(16843059, "maxRows");
        array.put(16843060, "maxItemsPerRow");
        array.put(16843061, "moreIcon");
        array.put(16843062, "max");
        array.put(16843063, "progress");
        array.put(16843064, "secondaryProgress");
        array.put(16843065, "indeterminate");
        array.put(16843066, "indeterminateOnly");
        array.put(16843067, "indeterminateDrawable");
        array.put(16843068, "progressDrawable");
        array.put(16843069, "indeterminateDuration");
        array.put(16843070, "indeterminateBehavior");
        array.put(16843071, "minWidth");
        array.put(16843072, "minHeight");
        array.put(16843073, "interpolator");
        array.put(16843074, "thumb");
        array.put(16843075, "thumbOffset");
        array.put(16843076, "numStars");
        array.put(16843077, "rating");
        array.put(16843078, "stepSize");
        array.put(16843079, "isIndicator");
        array.put(16843080, "checkedButton");
        array.put(16843081, "stretchColumns");
        array.put(16843082, "shrinkColumns");
        array.put(16843083, "collapseColumns");
        array.put(16843084, "layout_column");
        array.put(16843085, "layout_span");
        array.put(16843086, "bufferType");
        array.put(16843087, "text");
        array.put(16843088, "hint");
        array.put(16843089, "textScaleX");
        array.put(16843090, "cursorVisible");
        array.put(16843091, "maxLines");
        array.put(16843092, "lines");
        array.put(16843093, "height");
        array.put(16843094, "minLines");
        array.put(16843095, "maxEms");
        array.put(16843096, "ems");
        array.put(16843097, "width");
        array.put(16843098, "minEms");
        array.put(16843099, "scrollHorizontally");
        array.put(16843100, "password");
        array.put(16843101, "singleLine");
        array.put(16843102, "selectAllOnFocus");
        array.put(16843103, "includeFontPadding");
        array.put(16843104, "maxLength");
        array.put(16843105, "shadowColor");
        array.put(16843106, "shadowDx");
        array.put(16843107, "shadowDy");
        array.put(16843108, "shadowRadius");
        array.put(16843109, "numeric");
        array.put(16843110, "digits");
        array.put(16843111, "phoneNumber");
        array.put(16843112, "inputMethod");
        array.put(16843113, "capitalize");
        array.put(16843114, "autoText");
        array.put(16843115, "editable");
        array.put(16843116, "freezesText");
        array.put(16843117, "drawableTop");
        array.put(16843118, "drawableBottom");
        array.put(16843119, "drawableLeft");
        array.put(16843120, "drawableRight");
        array.put(16843121, "drawablePadding");
        array.put(16843122, "completionHint");
        array.put(16843123, "completionHintView");
        array.put(16843124, "completionThreshold");
        array.put(16843125, "dropDownSelector");
        array.put(16843126, "popupBackground");
        array.put(16843127, "inAnimation");
        array.put(16843128, "outAnimation");
        array.put(16843129, "flipInterval");
        array.put(16843130, "fillViewport");
        array.put(16843131, "prompt");
        array.put(16843132, "startYear");
        array.put(16843133, "endYear");
        array.put(16843134, "mode");
        array.put(16843135, "layout_x");
        array.put(16843136, "layout_y");
        array.put(16843137, "layout_weight");
        array.put(16843138, "layout_toLeftOf");
        array.put(16843139, "layout_toRightOf");
        array.put(16843140, "layout_above");
        array.put(16843141, "layout_below");
        array.put(16843142, "layout_alignBaseline");
        array.put(16843143, "layout_alignLeft");
        array.put(16843144, "layout_alignTop");
        array.put(16843145, "layout_alignRight");
        array.put(16843146, "layout_alignBottom");
        array.put(16843147, "layout_alignParentLeft");
        array.put(16843148, "layout_alignParentTop");
        array.put(16843149, "layout_alignParentRight");
        array.put(16843150, "layout_alignParentBottom");
        array.put(16843151, "layout_centerInParent");
        array.put(16843152, "layout_centerHorizontal");
        array.put(16843153, "layout_centerVertical");
        array.put(16843154, "layout_alignWithParentIfMissing");
        array.put(16843155, "layout_scale");
        array.put(16843156, "visible");
        array.put(16843157, "variablePadding");
        array.put(16843158, "constantSize");
        array.put(16843159, "oneshot");
        array.put(16843160, "duration");
        array.put(16843161, "drawable");
        array.put(16843162, "shape");
        array.put(16843163, "innerRadiusRatio");
        array.put(16843164, "thicknessRatio");
        array.put(16843165, "startColor");
        array.put(16843166, "endColor");
        array.put(16843167, "useLevel");
        array.put(16843168, "angle");
        array.put(16843169, "type");
        array.put(16843170, "centerX");
        array.put(16843171, "centerY");
        array.put(16843172, "gradientRadius");
        array.put(16843173, "color");
        array.put(16843174, "dashWidth");
        array.put(16843175, "dashGap");
        array.put(16843176, "radius");
        array.put(16843177, "topLeftRadius");
        array.put(16843178, "topRightRadius");
        array.put(16843179, "bottomLeftRadius");
        array.put(16843180, "bottomRightRadius");
        array.put(16843181, "left");
        array.put(16843182, "top");
        array.put(16843183, "right");
        array.put(16843184, "bottom");
        array.put(16843185, "minLevel");
        array.put(16843186, "maxLevel");
        array.put(16843187, "fromDegrees");
        array.put(16843188, "toDegrees");
        array.put(16843189, "pivotX");
        array.put(16843190, "pivotY");
        array.put(16843191, "insetLeft");
        array.put(16843192, "insetRight");
        array.put(16843193, "insetTop");
        array.put(16843194, "insetBottom");
        array.put(16843195, "shareInterpolator");
        array.put(16843196, "fillBefore");
        array.put(16843197, "fillAfter");
        array.put(16843198, "startOffset");
        array.put(16843199, "repeatCount");
        array.put(16843200, "repeatMode");
        array.put(16843201, "zAdjustment");
        array.put(16843202, "fromXScale");
        array.put(16843203, "toXScale");
        array.put(16843204, "fromYScale");
        array.put(16843205, "toYScale");
        array.put(16843206, "fromXDelta");
        array.put(16843207, "toXDelta");
        array.put(16843208, "fromYDelta");
        array.put(16843209, "toYDelta");
        array.put(16843210, "fromAlpha");
        array.put(16843211, "toAlpha");
        array.put(16843212, "delay");
        array.put(16843213, "animation");
        array.put(16843214, "animationOrder");
        array.put(16843215, "columnDelay");
        array.put(16843216, "rowDelay");
        array.put(16843217, "direction");
        array.put(16843218, "directionPriority");
        array.put(16843219, "factor");
        array.put(16843220, "cycles");
        array.put(16843221, "searchMode");
        array.put(16843222, "searchSuggestAuthority");
        array.put(16843223, "searchSuggestPath");
        array.put(16843224, "searchSuggestSelection");
        array.put(16843225, "searchSuggestIntentAction");
        array.put(16843226, "searchSuggestIntentData");
        array.put(16843227, "queryActionMsg");
        array.put(16843228, "suggestActionMsg");
        array.put(16843229, "suggestActionMsgColumn");
        array.put(16843230, "menuCategory");
        array.put(16843231, "orderInCategory");
        array.put(16843232, "checkableBehavior");
        array.put(16843233, "title");
        array.put(16843234, "titleCondensed");
        array.put(16843235, "alphabeticShortcut");
        array.put(16843236, "numericShortcut");
        array.put(16843237, "checkable");
        array.put(16843238, "selectable");
        array.put(16843239, "orderingFromXml");
        array.put(16843240, "key");
        array.put(16843241, "summary");
        array.put(16843242, "order");
        array.put(16843243, "widgetLayout");
        array.put(16843244, "dependency");
        array.put(16843245, "defaultValue");
        array.put(16843246, "shouldDisableView");
        array.put(16843247, "summaryOn");
        array.put(16843248, "summaryOff");
        array.put(16843249, "disableDependentsState");
        array.put(16843250, "dialogTitle");
        array.put(16843251, "dialogMessage");
        array.put(16843252, "dialogIcon");
        array.put(16843253, "positiveButtonText");
        array.put(16843254, "negativeButtonText");
        array.put(16843255, "dialogLayout");
        array.put(16843256, "entryValues");
        array.put(16843257, "ringtoneType");
        array.put(16843258, "showDefault");
        array.put(16843259, "showSilent");
        array.put(16843260, "scaleWidth");
        array.put(16843261, "scaleHeight");
        array.put(16843262, "scaleGravity");
        array.put(16843263, "ignoreGravity");
        array.put(16843264, "foregroundGravity");
        array.put(16843265, "tileMode");
        array.put(16843266, "targetActivity");
        array.put(16843267, "alwaysRetainTaskState");
        array.put(16843268, "allowTaskReparenting");
        array.put(16843269, "searchButtonText");
        array.put(16843270, "colorForegroundInverse");
        array.put(16843271, "textAppearanceButton");
        array.put(16843272, "listSeparatorTextViewStyle");
        array.put(16843273, "streamType");
        array.put(16843274, "clipOrientation");
        array.put(16843275, "centerColor");
        array.put(16843276, "minSdkVersion");
        array.put(16843277, "windowFullscreen");
        array.put(16843278, "unselectedAlpha");
        array.put(16843279, "progressBarStyleSmallTitle");
        array.put(16843280, "ratingBarStyleIndicator");
        array.put(16843281, "apiKey");
        array.put(16843282, "textColorTertiary");
        array.put(16843283, "textColorTertiaryInverse");
        array.put(16843284, "listDivider");
        array.put(16843285, "soundEffectsEnabled");
        array.put(16843286, "keepScreenOn");
        array.put(16843287, "lineSpacingExtra");
        array.put(16843288, "lineSpacingMultiplier");
        array.put(16843289, "listChoiceIndicatorSingle");
        array.put(16843290, "listChoiceIndicatorMultiple");
        array.put(16843291, "versionCode");
        array.put(16843292, "versionName");
        array.put(16843293, "marqueeRepeatLimit");
        array.put(16843294, "windowNoDisplay");
        array.put(16843295, "backgroundDimEnabled");
        array.put(16843296, "inputType");
        array.put(16843297, "isDefault");
        array.put(16843298, "windowDisablePreview");
        array.put(16843299, "privateImeOptions");
        array.put(16843300, "editorExtras");
        array.put(16843301, "settingsActivity");
        array.put(16843302, "fastScrollEnabled");
        array.put(16843303, "reqTouchScreen");
        array.put(16843304, "reqKeyboardType");
        array.put(16843305, "reqHardKeyboard");
        array.put(16843306, "reqNavigation");
        array.put(16843307, "windowSoftInputMode");
        array.put(16843308, "imeFullscreenBackground");
        array.put(16843309, "noHistory");
        array.put(16843310, "headerDividersEnabled");
        array.put(16843311, "footerDividersEnabled");
        array.put(16843312, "candidatesTextStyleSpans");
        array.put(16843313, "smoothScrollbar");
        array.put(16843314, "reqFiveWayNav");
        array.put(16843315, "keyBackground");
        array.put(16843316, "keyTextSize");
        array.put(16843317, "labelTextSize");
        array.put(16843318, "keyTextColor");
        array.put(16843319, "keyPreviewLayout");
        array.put(16843320, "keyPreviewOffset");
        array.put(16843321, "keyPreviewHeight");
        array.put(16843322, "verticalCorrection");
        array.put(16843323, "popupLayout");
        array.put(16843324, "state_long_pressable");
        array.put(16843325, "keyWidth");
        array.put(16843326, "keyHeight");
        array.put(16843327, "horizontalGap");
        array.put(16843328, "verticalGap");
        array.put(16843329, "rowEdgeFlags");
        array.put(16843330, "codes");
        array.put(16843331, "popupKeyboard");
        array.put(16843332, "popupCharacters");
        array.put(16843333, "keyEdgeFlags");
        array.put(16843334, "isModifier");
        array.put(16843335, "isSticky");
        array.put(16843336, "isRepeatable");
        array.put(16843337, "iconPreview");
        array.put(16843338, "keyOutputText");
        array.put(16843339, "keyLabel");
        array.put(16843340, "keyIcon");
        array.put(16843341, "keyboardMode");
        array.put(16843342, "isScrollContainer");
        array.put(16843343, "fillEnabled");
        array.put(16843344, "updatePeriodMillis");
        array.put(16843345, "initialLayout");
        array.put(16843346, "voiceSearchMode");
        array.put(16843347, "voiceLanguageModel");
        array.put(16843348, "voicePromptText");
        array.put(16843349, "voiceLanguage");
        array.put(16843350, "voiceMaxResults");
        array.put(16843351, "bottomOffset");
        array.put(16843352, "topOffset");
        array.put(16843353, "allowSingleTap");
        array.put(16843354, "handle");
        array.put(16843355, "content");
        array.put(16843356, "animateOnClick");
        array.put(16843357, "configure");
        array.put(16843358, "hapticFeedbackEnabled");
        array.put(16843359, "innerRadius");
        array.put(16843360, "thickness");
        array.put(16843361, "sharedUserLabel");
        array.put(16843362, "dropDownWidth");
        array.put(16843363, "dropDownAnchor");
        array.put(16843364, "imeOptions");
        array.put(16843365, "imeActionLabel");
        array.put(16843366, "imeActionId");
        array.put(16843368, "imeExtractEnterAnimation");
        array.put(16843369, "imeExtractExitAnimation");
        array.put(16843370, "tension");
        array.put(16843371, "extraTension");
        array.put(16843372, "anyDensity");
        array.put(16843373, "searchSuggestThreshold");
        array.put(16843374, "includeInGlobalSearch");
        array.put(16843375, "onClick");
        array.put(16843376, "targetSdkVersion");
        array.put(16843377, "maxSdkVersion");
        array.put(16843378, "testOnly");
        array.put(16843379, "contentDescription");
        array.put(16843380, "gestureStrokeWidth");
        array.put(16843381, "gestureColor");
        array.put(16843382, "uncertainGestureColor");
        array.put(16843383, "fadeOffset");
        array.put(16843384, "fadeDuration");
        array.put(16843385, "gestureStrokeType");
        array.put(16843386, "gestureStrokeLengthThreshold");
        array.put(16843387, "gestureStrokeSquarenessThreshold");
        array.put(16843388, "gestureStrokeAngleThreshold");
        array.put(16843389, "eventsInterceptionEnabled");
        array.put(16843390, "fadeEnabled");
        array.put(16843391, "backupAgent");
        array.put(16843392, "allowBackup");
        array.put(16843393, "glEsVersion");
        array.put(16843394, "queryAfterZeroResults");
        array.put(16843395, "dropDownHeight");
        array.put(16843396, "smallScreens");
        array.put(16843397, "normalScreens");
        array.put(16843398, "largeScreens");
        array.put(16843399, "progressBarStyleInverse");
        array.put(16843400, "progressBarStyleSmallInverse");
        array.put(16843401, "progressBarStyleLargeInverse");
        array.put(16843402, "searchSettingsDescription");
        array.put(16843403, "textColorPrimaryInverseDisableOnly");
        array.put(16843404, "autoUrlDetect");
        array.put(16843405, "resizeable");
        array.put(16843406, "required");
        array.put(16843407, "accountType");
        array.put(16843408, "contentAuthority");
        array.put(16843409, "userVisible");
        array.put(16843410, "windowShowWallpaper");
        array.put(16843411, "wallpaperOpenEnterAnimation");
        array.put(16843412, "wallpaperOpenExitAnimation");
        array.put(16843413, "wallpaperCloseEnterAnimation");
        array.put(16843414, "wallpaperCloseExitAnimation");
        array.put(16843415, "wallpaperIntraOpenEnterAnimation");
        array.put(16843416, "wallpaperIntraOpenExitAnimation");
        array.put(16843417, "wallpaperIntraCloseEnterAnimation");
        array.put(16843418, "wallpaperIntraCloseExitAnimation");
        array.put(16843419, "supportsUploading");
        array.put(16843420, "killAfterRestore");
        array.put(16843421, "restoreNeedsApplication");
        array.put(16843422, "smallIcon");
        array.put(16843423, "accountPreferences");
        array.put(16843424, "textAppearanceSearchResultSubtitle");
        array.put(16843425, "textAppearanceSearchResultTitle");
        array.put(16843426, "summaryColumn");
        array.put(16843427, "detailColumn");
        array.put(16843428, "detailSocialSummary");
        array.put(16843429, "thumbnail");
        array.put(16843430, "detachWallpaper");
        array.put(16843431, "finishOnCloseSystemDialogs");
        array.put(16843432, "scrollbarFadeDuration");
        array.put(16843433, "scrollbarDefaultDelayBeforeFade");
        array.put(16843434, "fadeScrollbars");
        array.put(16843435, "colorBackgroundCacheHint");
        array.put(16843436, "dropDownHorizontalOffset");
        array.put(16843437, "dropDownVerticalOffset");
        array.put(16843438, "quickContactBadgeStyleWindowSmall");
        array.put(16843439, "quickContactBadgeStyleWindowMedium");
        array.put(16843440, "quickContactBadgeStyleWindowLarge");
        array.put(16843441, "quickContactBadgeStyleSmallWindowSmall");
        array.put(16843442, "quickContactBadgeStyleSmallWindowMedium");
        array.put(16843443, "quickContactBadgeStyleSmallWindowLarge");
        array.put(16843444, "author");
        array.put(16843445, "autoStart");
        array.put(16843446, "expandableListViewWhiteStyle");
        array.put(16843447, "installLocation");
        array.put(16843448, "vmSafeMode");
        array.put(16843449, "webTextViewStyle");
        array.put(16843450, "restoreAnyVersion");
        array.put(16843451, "tabStripLeft");
        array.put(16843452, "tabStripRight");
        array.put(16843453, "tabStripEnabled");
        array.put(16843454, "logo");
        array.put(16843455, "xlargeScreens");
        array.put(16843456, "immersive");
        array.put(16843457, "overScrollMode");
        array.put(16843458, "overScrollHeader");
        array.put(16843459, "overScrollFooter");
        array.put(16843460, "filterTouchesWhenObscured");
        array.put(16843461, "textSelectHandleLeft");
        array.put(16843462, "textSelectHandleRight");
        array.put(16843463, "textSelectHandle");
        array.put(16843464, "textSelectHandleWindowStyle");
        array.put(16843465, "popupAnimationStyle");
        array.put(16843466, "screenSize");
        array.put(16843467, "screenDensity");
        array.put(16843468, "allContactsName");
        array.put(16843469, "windowActionBar");
        array.put(16843470, "actionBarStyle");
        array.put(16843471, "navigationMode");
        array.put(16843472, "displayOptions");
        array.put(16843473, "subtitle");
        array.put(16843474, "customNavigationLayout");
        array.put(16843475, "hardwareAccelerated");
        array.put(16843476, "measureWithLargestChild");
        array.put(16843477, "animateFirstView");
        array.put(16843478, "dropDownSpinnerStyle");
        array.put(16843479, "actionDropDownStyle");
        array.put(16843480, "actionButtonStyle");
        array.put(16843481, "showAsAction");
        array.put(16843482, "previewImage");
        array.put(16843483, "actionModeBackground");
        array.put(16843484, "actionModeCloseDrawable");
        array.put(16843485, "windowActionModeOverlay");
        array.put(16843486, "valueFrom");
        array.put(16843487, "valueTo");
        array.put(16843488, "valueType");
        array.put(16843489, "propertyName");
        array.put(16843490, "ordering");
        array.put(16843491, "fragment");
        array.put(16843492, "windowActionBarOverlay");
        array.put(16843493, "fragmentOpenEnterAnimation");
        array.put(16843494, "fragmentOpenExitAnimation");
        array.put(16843495, "fragmentCloseEnterAnimation");
        array.put(16843496, "fragmentCloseExitAnimation");
        array.put(16843497, "fragmentFadeEnterAnimation");
        array.put(16843498, "fragmentFadeExitAnimation");
        array.put(16843499, "actionBarSize");
        array.put(16843500, "imeSubtypeLocale");
        array.put(16843501, "imeSubtypeMode");
        array.put(16843502, "imeSubtypeExtraValue");
        array.put(16843503, "splitMotionEvents");
        array.put(16843504, "listChoiceBackgroundIndicator");
        array.put(16843505, "spinnerMode");
        array.put(16843506, "animateLayoutChanges");
        array.put(16843507, "actionBarTabStyle");
        array.put(16843508, "actionBarTabBarStyle");
        array.put(16843509, "actionBarTabTextStyle");
        array.put(16843510, "actionOverflowButtonStyle");
        array.put(16843511, "actionModeCloseButtonStyle");
        array.put(16843512, "titleTextStyle");
        array.put(16843513, "subtitleTextStyle");
        array.put(16843514, "iconifiedByDefault");
        array.put(16843515, "actionLayout");
        array.put(16843516, "actionViewClass");
        array.put(16843517, "activatedBackgroundIndicator");
        array.put(16843518, "state_activated");
        array.put(16843519, "listPopupWindowStyle");
        array.put(16843520, "popupMenuStyle");
        array.put(16843521, "textAppearanceLargePopupMenu");
        array.put(16843522, "textAppearanceSmallPopupMenu");
        array.put(16843523, "breadCrumbTitle");
        array.put(16843524, "breadCrumbShortTitle");
        array.put(16843525, "listDividerAlertDialog");
        array.put(16843526, "textColorAlertDialogListItem");
        array.put(16843527, "loopViews");
        array.put(16843528, "dialogTheme");
        array.put(16843529, "alertDialogTheme");
        array.put(16843530, "dividerVertical");
        array.put(16843531, "homeAsUpIndicator");
        array.put(16843532, "enterFadeDuration");
        array.put(16843533, "exitFadeDuration");
        array.put(16843534, "selectableItemBackground");
        array.put(16843535, "autoAdvanceViewId");
        array.put(16843536, "useIntrinsicSizeAsMinimum");
        array.put(16843537, "actionModeCutDrawable");
        array.put(16843538, "actionModeCopyDrawable");
        array.put(16843539, "actionModePasteDrawable");
        array.put(16843540, "textEditPasteWindowLayout");
        array.put(16843541, "textEditNoPasteWindowLayout");
        array.put(16843542, "textIsSelectable");
        array.put(16843543, "windowEnableSplitTouch");
        array.put(16843544, "indeterminateProgressStyle");
        array.put(16843545, "progressBarPadding");
        array.put(16843546, "animationResolution");
        array.put(16843547, "state_accelerated");
        array.put(16843548, "baseline");
        array.put(16843549, "homeLayout");
        array.put(16843550, "opacity");
        array.put(16843551, "alpha");
        array.put(16843552, "transformPivotX");
        array.put(16843553, "transformPivotY");
        array.put(16843554, "translationX");
        array.put(16843555, "translationY");
        array.put(16843556, "scaleX");
        array.put(16843557, "scaleY");
        array.put(16843558, "rotation");
        array.put(16843559, "rotationX");
        array.put(16843560, "rotationY");
        array.put(16843561, "showDividers");
        array.put(16843562, "dividerPadding");
        array.put(16843563, "borderlessButtonStyle");
        array.put(16843564, "dividerHorizontal");
        array.put(16843565, "itemPadding");
        array.put(16843566, "buttonBarStyle");
        array.put(16843567, "buttonBarButtonStyle");
        array.put(16843568, "segmentedButtonStyle");
        array.put(16843569, "staticWallpaperPreview");
        array.put(16843570, "allowParallelSyncs");
        array.put(16843571, "isAlwaysSyncable");
        array.put(16843572, "verticalScrollbarPosition");
        array.put(16843573, "fastScrollAlwaysVisible");
        array.put(16843574, "fastScrollThumbDrawable");
        array.put(16843575, "fastScrollPreviewBackgroundLeft");
        array.put(16843576, "fastScrollPreviewBackgroundRight");
        array.put(16843577, "fastScrollTrackDrawable");
        array.put(16843578, "fastScrollOverlayPosition");
        array.put(16843579, "customTokens");
        array.put(16843580, "nextFocusForward");
        array.put(16843581, "firstDayOfWeek");
        array.put(16843582, "showWeekNumber");
        array.put(16843583, "minDate");
        array.put(16843584, "maxDate");
        array.put(16843585, "shownWeekCount");
        array.put(16843586, "selectedWeekBackgroundColor");
        array.put(16843587, "focusedMonthDateColor");
        array.put(16843588, "unfocusedMonthDateColor");
        array.put(16843589, "weekNumberColor");
        array.put(16843590, "weekSeparatorLineColor");
        array.put(16843591, "selectedDateVerticalBar");
        array.put(16843592, "weekDayTextAppearance");
        array.put(16843593, "dateTextAppearance");
        array.put(16843594, "solidColor");
        array.put(16843595, "spinnersShown");
        array.put(16843596, "calendarViewShown");
        array.put(16843597, "state_multiline");
        array.put(16843598, "detailsElementBackground");
        array.put(16843599, "textColorHighlightInverse");
        array.put(16843600, "textColorLinkInverse");
        array.put(16843601, "editTextColor");
        array.put(16843602, "editTextBackground");
        array.put(16843603, "horizontalScrollViewStyle");
        array.put(16843604, "layerType");
        array.put(16843605, "alertDialogIcon");
        array.put(16843606, "windowMinWidthMajor");
        array.put(16843607, "windowMinWidthMinor");
        array.put(16843608, "queryHint");
        array.put(16843609, "fastScrollTextColor");
        array.put(16843610, "largeHeap");
        array.put(16843611, "windowCloseOnTouchOutside");
        array.put(16843612, "datePickerStyle");
        array.put(16843613, "calendarViewStyle");
        array.put(16843614, "textEditSidePasteWindowLayout");
        array.put(16843615, "textEditSideNoPasteWindowLayout");
        array.put(16843616, "actionMenuTextAppearance");
        array.put(16843617, "actionMenuTextColor");
        array.put(16843618, "textCursorDrawable");
        array.put(16843619, "resizeMode");
        array.put(16843620, "requiresSmallestWidthDp");
        array.put(16843621, "compatibleWidthLimitDp");
        array.put(16843622, "largestWidthLimitDp");
        array.put(16843623, "state_hovered");
        array.put(16843624, "state_drag_can_accept");
        array.put(16843625, "state_drag_hovered");
        array.put(16843626, "stopWithTask");
        array.put(16843627, "switchTextOn");
        array.put(16843628, "switchTextOff");
        array.put(16843629, "switchPreferenceStyle");
        array.put(16843630, "switchTextAppearance");
        array.put(16843631, "track");
        array.put(16843632, "switchMinWidth");
        array.put(16843633, "switchPadding");
        array.put(16843634, "thumbTextPadding");
        array.put(16843635, "textSuggestionsWindowStyle");
        array.put(16843636, "textEditSuggestionItemLayout");
        array.put(16843637, "rowCount");
        array.put(16843638, "rowOrderPreserved");
        array.put(16843639, "columnCount");
        array.put(16843640, "columnOrderPreserved");
        array.put(16843641, "useDefaultMargins");
        array.put(16843642, "alignmentMode");
        array.put(16843643, "layout_row");
        array.put(16843644, "layout_rowSpan");
        array.put(16843645, "layout_columnSpan");
        array.put(16843646, "actionModeSelectAllDrawable");
        array.put(16843647, "isAuxiliary");
        array.put(16843648, "accessibilityEventTypes");
        array.put(16843649, "packageNames");
        array.put(16843650, "accessibilityFeedbackType");
        array.put(16843651, "notificationTimeout");
        array.put(16843652, "accessibilityFlags");
        array.put(16843653, "canRetrieveWindowContent");
        array.put(16843654, "listPreferredItemHeightLarge");
        array.put(16843655, "listPreferredItemHeightSmall");
        array.put(16843656, "actionBarSplitStyle");
        array.put(16843657, "actionProviderClass");
        array.put(16843658, "backgroundStacked");
        array.put(16843659, "backgroundSplit");
        array.put(16843660, "textAllCaps");
        array.put(16843661, "colorPressedHighlight");
        array.put(16843662, "colorLongPressedHighlight");
        array.put(16843663, "colorFocusedHighlight");
        array.put(16843664, "colorActivatedHighlight");
        array.put(16843665, "colorMultiSelectHighlight");
        array.put(16843666, "drawableStart");
        array.put(16843667, "drawableEnd");
        array.put(16843668, "actionModeStyle");
        array.put(16843669, "minResizeWidth");
        array.put(16843670, "minResizeHeight");
        array.put(16843671, "actionBarWidgetTheme");
        array.put(16843672, "uiOptions");
        array.put(16843673, "subtypeLocale");
        array.put(16843674, "subtypeExtraValue");
        array.put(16843675, "actionBarDivider");
        array.put(16843676, "actionBarItemBackground");
        array.put(16843677, "actionModeSplitBackground");
        array.put(16843678, "textAppearanceListItem");
        array.put(16843679, "textAppearanceListItemSmall");
        array.put(16843680, "targetDescriptions");
        array.put(16843681, "directionDescriptions");
        array.put(16843682, "overridesImplicitlyEnabledSubtype");
        array.put(16843683, "listPreferredItemPaddingLeft");
        array.put(16843684, "listPreferredItemPaddingRight");
        array.put(16843685, "requiresFadingEdge");
        array.put(16843686, "publicKey");
        array.put(16843687, "parentActivityName");
        array.put(16843689, "isolatedProcess");
        array.put(16843690, "importantForAccessibility");
        array.put(16843691, "keyboardLayout");
        array.put(16843692, "fontFamily");
        array.put(16843693, "mediaRouteButtonStyle");
        array.put(16843694, "mediaRouteTypes");
        array.put(16843695, "supportsRtl");
        array.put(16843696, "textDirection");
        array.put(16843697, "textAlignment");
        array.put(16843698, "layoutDirection");
        array.put(16843699, "paddingStart");
        array.put(16843700, "paddingEnd");
        array.put(16843701, "layout_marginStart");
        array.put(16843702, "layout_marginEnd");
        array.put(16843703, "layout_toStartOf");
        array.put(16843704, "layout_toEndOf");
        array.put(16843705, "layout_alignStart");
        array.put(16843706, "layout_alignEnd");
        array.put(16843707, "layout_alignParentStart");
        array.put(16843708, "layout_alignParentEnd");
        array.put(16843709, "listPreferredItemPaddingStart");
        array.put(16843710, "listPreferredItemPaddingEnd");
        array.put(16843711, "singleUser");
        array.put(16843712, "presentationTheme");
        array.put(16843713, "subtypeId");
        array.put(16843714, "initialKeyguardLayout");
        array.put(16843716, "widgetCategory");
        array.put(16843717, "permissionGroupFlags");
        array.put(16843718, "labelFor");
        array.put(16843719, "permissionFlags");
        array.put(16843720, "checkedTextViewStyle");
        array.put(16843721, "showOnLockScreen");
        array.put(16843722, "format12Hour");
        array.put(16843723, "format24Hour");
        array.put(16843724, "timeZone");
        array.put(16843725, "mipMap");
        array.put(16843726, "mirrorForRtl");
        array.put(16843727, "windowOverscan");
        array.put(16843728, "requiredForAllUsers");
        array.put(16843729, "indicatorStart");
        array.put(16843730, "indicatorEnd");
        array.put(16843731, "childIndicatorStart");
        array.put(16843732, "childIndicatorEnd");
        array.put(16843733, "restrictedAccountType");
        array.put(16843734, "requiredAccountType");
        array.put(16843735, "canRequestTouchExplorationMode");
        array.put(16843736, "canRequestEnhancedWebAccessibility");
        array.put(16843737, "canRequestFilterKeyEvents");
        array.put(16843738, "layoutMode");
        array.put(16843739, "keySet");
        array.put(16843740, "targetId");
        array.put(16843741, "fromScene");
        array.put(16843742, "toScene");
        array.put(16843743, "transition");
        array.put(16843744, "transitionOrdering");
        array.put(16843745, "fadingMode");
        array.put(16843746, "startDelay");
        array.put(16843747, "ssp");
        array.put(16843748, "sspPrefix");
        array.put(16843749, "sspPattern");
        array.put(16843750, "addPrintersActivity");
        array.put(16843751, "vendor");
        array.put(16843752, "category");
        array.put(16843753, "isAsciiCapable");
        array.put(16843754, "autoMirrored");
        array.put(16843755, "supportsSwitchingToNextInputMethod");
        array.put(16843756, "requireDeviceUnlock");
        array.put(16843757, "apduServiceBanner");
        array.put(16843758, "accessibilityLiveRegion");
        array.put(16843759, "windowTranslucentStatus");
        array.put(16843760, "windowTranslucentNavigation");
        array.put(16843761, "advancedPrintOptionsActivity");
        array.put(16843762, "banner");
        array.put(16843763, "windowSwipeToDismiss");
        array.put(16843764, "isGame");
        array.put(16843765, "allowEmbedded");
        array.put(16843766, "setupActivity");
        array.put(16843767, "fastScrollStyle");
        array.put(16843768, "windowContentTransitions");
        array.put(16843769, "windowContentTransitionManager");
        array.put(16843770, "translationZ");
        array.put(16843771, "tintMode");
        array.put(16843772, "controlX1");
        array.put(16843773, "controlY1");
        array.put(16843774, "controlX2");
        array.put(16843775, "controlY2");
        array.put(16843776, "transitionName");
        array.put(16843777, "transitionGroup");
        array.put(16843778, "viewportWidth");
        array.put(16843779, "viewportHeight");
        array.put(16843780, "fillColor");
        array.put(16843781, "pathData");
        array.put(16843782, "strokeColor");
        array.put(16843783, "strokeWidth");
        array.put(16843784, "trimPathStart");
        array.put(16843785, "trimPathEnd");
        array.put(16843786, "trimPathOffset");
        array.put(16843787, "strokeLineCap");
        array.put(16843788, "strokeLineJoin");
        array.put(16843789, "strokeMiterLimit");
        array.put(16843817, "colorControlNormal");
        array.put(16843818, "colorControlActivated");
        array.put(16843819, "colorButtonNormal");
        array.put(16843820, "colorControlHighlight");
        array.put(16843821, "persistableMode");
        array.put(16843822, "titleTextAppearance");
        array.put(16843823, "subtitleTextAppearance");
        array.put(16843824, "slideEdge");
        array.put(16843825, "actionBarTheme");
        array.put(16843826, "textAppearanceListItemSecondary");
        array.put(16843827, "colorPrimary");
        array.put(16843828, "colorPrimaryDark");
        array.put(16843829, "colorAccent");
        array.put(16843830, "nestedScrollingEnabled");
        array.put(16843831, "windowEnterTransition");
        array.put(16843832, "windowExitTransition");
        array.put(16843833, "windowSharedElementEnterTransition");
        array.put(16843834, "windowSharedElementExitTransition");
        array.put(16843835, "windowAllowReturnTransitionOverlap");
        array.put(16843836, "windowAllowEnterTransitionOverlap");
        array.put(16843837, "sessionService");
        array.put(16843838, "stackViewStyle");
        array.put(16843839, "switchStyle");
        array.put(16843840, "elevation");
        array.put(16843841, "excludeId");
        array.put(16843842, "excludeClass");
        array.put(16843843, "hideOnContentScroll");
        array.put(16843844, "actionOverflowMenuStyle");
        array.put(16843845, "documentLaunchMode");
        array.put(16843846, "maxRecents");
        array.put(16843847, "autoRemoveFromRecents");
        array.put(16843848, "stateListAnimator");
        array.put(16843849, "toId");
        array.put(16843850, "fromId");
        array.put(16843851, "reversible");
        array.put(16843852, "splitTrack");
        array.put(16843853, "targetName");
        array.put(16843854, "excludeName");
        array.put(16843855, "matchOrder");
        array.put(16843856, "windowDrawsSystemBarBackgrounds");
        array.put(16843857, "statusBarColor");
        array.put(16843858, "navigationBarColor");
        array.put(16843859, "contentInsetStart");
        array.put(16843860, "contentInsetEnd");
        array.put(16843861, "contentInsetLeft");
        array.put(16843862, "contentInsetRight");
        array.put(16843863, "paddingMode");
        array.put(16843864, "layout_rowWeight");
        array.put(16843865, "layout_columnWeight");
        array.put(16843866, "translateX");
        array.put(16843867, "translateY");
        array.put(16843868, "selectableItemBackgroundBorderless");
        array.put(16843869, "elegantTextHeight");
        array.put(16843870, "searchKeyphraseId");
        array.put(16843871, "searchKeyphrase");
        array.put(16843872, "searchKeyphraseSupportedLocales");
        array.put(16843873, "windowTransitionBackgroundFadeDuration");
        array.put(16843874, "overlapAnchor");
        array.put(16843875, "progressTint");
        array.put(16843876, "progressTintMode");
        array.put(16843877, "progressBackgroundTint");
        array.put(16843878, "progressBackgroundTintMode");
        array.put(16843879, "secondaryProgressTint");
        array.put(16843880, "secondaryProgressTintMode");
        array.put(16843881, "indeterminateTint");
        array.put(16843882, "indeterminateTintMode");
        array.put(16843883, "backgroundTint");
        array.put(16843884, "backgroundTintMode");
        array.put(16843885, "foregroundTint");
        array.put(16843886, "foregroundTintMode");
        array.put(16843887, "buttonTint");
        array.put(16843888, "buttonTintMode");
        array.put(16843889, "thumbTint");
        array.put(16843890, "thumbTintMode");
        array.put(16843891, "fullBackupOnly");
        array.put(16843892, "propertyXName");
        array.put(16843893, "propertyYName");
        array.put(16843894, "relinquishTaskIdentity");
        array.put(16843895, "tileModeX");
        array.put(16843896, "tileModeY");
        array.put(16843897, "actionModeShareDrawable");
        array.put(16843898, "actionModeFindDrawable");
        array.put(16843899, "actionModeWebSearchDrawable");
        array.put(16843900, "transitionVisibilityMode");
        array.put(16843901, "minimumHorizontalAngle");
        array.put(16843902, "minimumVerticalAngle");
        array.put(16843903, "maximumAngle");
        array.put(16843904, "searchViewStyle");
        array.put(16843905, "closeIcon");
        array.put(16843906, "goIcon");
        array.put(16843907, "searchIcon");
        array.put(16843908, "voiceIcon");
        array.put(16843909, "commitIcon");
        array.put(16843910, "suggestionRowLayout");
        array.put(16843911, "queryBackground");
        array.put(16843912, "submitBackground");
        array.put(16843913, "buttonBarPositiveButtonStyle");
        array.put(16843914, "buttonBarNeutralButtonStyle");
        array.put(16843915, "buttonBarNegativeButtonStyle");
        array.put(16843916, "popupElevation");
        array.put(16843917, "actionBarPopupTheme");
        array.put(16843918, "multiArch");
        array.put(16843919, "touchscreenBlocksFocus");
        array.put(16843920, "windowElevation");
        array.put(16843921, "launchTaskBehindTargetAnimation");
        array.put(16843922, "launchTaskBehindSourceAnimation");
        array.put(16843923, "restrictionType");
        array.put(16843924, "dayOfWeekBackground");
        array.put(16843925, "dayOfWeekTextAppearance");
        array.put(16843926, "headerMonthTextAppearance");
        array.put(16843927, "headerDayOfMonthTextAppearance");
        array.put(16843928, "headerYearTextAppearance");
        array.put(16843929, "yearListItemTextAppearance");
        array.put(16843930, "yearListSelectorColor");
        array.put(16843931, "calendarTextColor");
        array.put(16843932, "recognitionService");
        array.put(16843933, "timePickerStyle");
        array.put(16843934, "timePickerDialogTheme");
        array.put(16843935, "headerTimeTextAppearance");
        array.put(16843936, "headerAmPmTextAppearance");
        array.put(16843937, "numbersTextColor");
        array.put(16843938, "numbersBackgroundColor");
        array.put(16843939, "numbersSelectorColor");
        array.put(16843940, "amPmTextColor");
        array.put(16843941, "amPmBackgroundColor");
        array.put(16843942, "searchKeyphraseRecognitionFlags");
        array.put(16843943, "checkMarkTint");
        array.put(16843944, "checkMarkTintMode");
        array.put(16843945, "popupTheme");
        array.put(16843946, "toolbarStyle");
        array.put(16843947, "windowClipToOutline");
        array.put(16843948, "datePickerDialogTheme");
        array.put(16843949, "showText");
        array.put(16843950, "windowReturnTransition");
        array.put(16843951, "windowReenterTransition");
        array.put(16843952, "windowSharedElementReturnTransition");
        array.put(16843953, "windowSharedElementReenterTransition");
        array.put(16843954, "resumeWhilePausing");
        array.put(16843955, "datePickerMode");
        array.put(16843956, "timePickerMode");
        array.put(16843957, "inset");
        array.put(16843958, "letterSpacing");
        array.put(16843959, "fontFeatureSettings");
        array.put(16843960, "outlineProvider");
        array.put(16843961, "contentAgeHint");
        array.put(16843962, "country");
        array.put(16843963, "windowSharedElementsUseOverlay");
        array.put(16843964, "reparent");
        array.put(16843965, "reparentWithOverlay");
        array.put(16843966, "ambientShadowAlpha");
        array.put(16843967, "spotShadowAlpha");
        array.put(16843968, "navigationIcon");
        array.put(16843969, "navigationContentDescription");
        array.put(16843970, "fragmentExitTransition");
        array.put(16843971, "fragmentEnterTransition");
        array.put(16843972, "fragmentSharedElementEnterTransition");
        array.put(16843973, "fragmentReturnTransition");
        array.put(16843974, "fragmentSharedElementReturnTransition");
        array.put(16843975, "fragmentReenterTransition");
        array.put(16843976, "fragmentAllowEnterTransitionOverlap");
        array.put(16843977, "fragmentAllowReturnTransitionOverlap");
        array.put(16843978, "patternPathData");
        array.put(16843979, "strokeAlpha");
        array.put(16843980, "fillAlpha");
        array.put(16843981, "windowActivityTransitions");
        array.put(16843982, "colorEdgeEffect");
        array.put(16843983, "resizeClip");
        array.put(16843984, "collapseContentDescription");
        array.put(16843985, "accessibilityTraversalBefore");
        array.put(16843986, "accessibilityTraversalAfter");
        array.put(16843987, "dialogPreferredPadding");
        array.put(16843988, "searchHintIcon");
        return array;
    }

    @NonNull
    public static SparseArray<String> loadSystemStyles() {
        SparseArray<String> array = new SparseArray<>();
        array.put(16973824, "Animation");
        array.put(16973825, "Animation.Activity");
        array.put(16973826, "Animation.Dialog");
        array.put(16973910, "Animation.InputMethod");
        array.put(16973828, "Animation.Toast");
        array.put(16973827, "Animation.Translucent");
        array.put(16974287, "DeviceDefault.ButtonBar");
        array.put(16974288, "DeviceDefault.ButtonBar.AlertDialog");
        array.put(16974290, "DeviceDefault.Light.ButtonBar");
        array.put(16974291, "DeviceDefault.Light.ButtonBar.AlertDialog");
        array.put(16974292, "DeviceDefault.Light.SegmentedButton");
        array.put(16974289, "DeviceDefault.SegmentedButton");
        array.put(16974053, "Holo.ButtonBar");
        array.put(16974055, "Holo.ButtonBar.AlertDialog");
        array.put(16974054, "Holo.Light.ButtonBar");
        array.put(16974056, "Holo.Light.ButtonBar.AlertDialog");
        array.put(16974058, "Holo.Light.SegmentedButton");
        array.put(16974057, "Holo.SegmentedButton");
        array.put(16973879, "MediaButton");
        array.put(16973883, "MediaButton.Ffwd");
        array.put(16973881, "MediaButton.Next");
        array.put(16973885, "MediaButton.Pause");
        array.put(16973882, "MediaButton.Play");
        array.put(16973880, "MediaButton.Previous");
        array.put(16973884, "MediaButton.Rew");
        array.put(16973886, "TextAppearance");
        array.put(16974253, "TextAppearance.DeviceDefault");
        array.put(16974264, "TextAppearance.DeviceDefault.DialogWindowTitle");
        array.put(16974254, "TextAppearance.DeviceDefault.Inverse");
        array.put(16974255, "TextAppearance.DeviceDefault.Large");
        array.put(16974256, "TextAppearance.DeviceDefault.Large.Inverse");
        array.put(16974257, "TextAppearance.DeviceDefault.Medium");
        array.put(16974258, "TextAppearance.DeviceDefault.Medium.Inverse");
        array.put(16974262, "TextAppearance.DeviceDefault.SearchResult.Subtitle");
        array.put(16974261, "TextAppearance.DeviceDefault.SearchResult.Title");
        array.put(16974259, "TextAppearance.DeviceDefault.Small");
        array.put(16974260, "TextAppearance.DeviceDefault.Small.Inverse");
        array.put(16974265, "TextAppearance.DeviceDefault.Widget");
        array.put(16974286, "TextAppearance.DeviceDefault.Widget.ActionBar.Menu");
        array.put(16974279, "TextAppearance.DeviceDefault.Widget.ActionBar.Subtitle");
        array.put(16974283, "TextAppearance.DeviceDefault.Widget.ActionBar.Subtitle.Inverse");
        array.put(16974278, "TextAppearance.DeviceDefault.Widget.ActionBar.Title");
        array.put(16974282, "TextAppearance.DeviceDefault.Widget.ActionBar.Title.Inverse");
        array.put(16974281, "TextAppearance.DeviceDefault.Widget.ActionMode.Subtitle");
        array.put(16974285, "TextAppearance.DeviceDefault.Widget.ActionMode.Subtitle.Inverse");
        array.put(16974280, "TextAppearance.DeviceDefault.Widget.ActionMode.Title");
        array.put(16974284, "TextAppearance.DeviceDefault.Widget.ActionMode.Title.Inverse");
        array.put(16974266, "TextAppearance.DeviceDefault.Widget.Button");
        array.put(16974271, "TextAppearance.DeviceDefault.Widget.DropDownHint");
        array.put(16974272, "TextAppearance.DeviceDefault.Widget.DropDownItem");
        array.put(16974274, "TextAppearance.DeviceDefault.Widget.EditText");
        array.put(16974267, "TextAppearance.DeviceDefault.Widget.IconMenu.Item");
        array.put(16974275, "TextAppearance.DeviceDefault.Widget.PopupMenu");
        array.put(16974276, "TextAppearance.DeviceDefault.Widget.PopupMenu.Large");
        array.put(16974277, "TextAppearance.DeviceDefault.Widget.PopupMenu.Small");
        array.put(16974268, "TextAppearance.DeviceDefault.Widget.TabWidget");
        array.put(16974269, "TextAppearance.DeviceDefault.Widget.TextView");
        array.put(16974270, "TextAppearance.DeviceDefault.Widget.TextView.PopupMenu");
        array.put(16974273, "TextAppearance.DeviceDefault.Widget.TextView.SpinnerItem");
        array.put(16974263, "TextAppearance.DeviceDefault.WindowTitle");
        array.put(16973889, "TextAppearance.DialogWindowTitle");
        array.put(16974075, "TextAppearance.Holo");
        array.put(16974103, "TextAppearance.Holo.DialogWindowTitle");
        array.put(16974076, "TextAppearance.Holo.Inverse");
        array.put(16974077, "TextAppearance.Holo.Large");
        array.put(16974078, "TextAppearance.Holo.Large.Inverse");
        array.put(16974079, "TextAppearance.Holo.Medium");
        array.put(16974080, "TextAppearance.Holo.Medium.Inverse");
        array.put(16974084, "TextAppearance.Holo.SearchResult.Subtitle");
        array.put(16974083, "TextAppearance.Holo.SearchResult.Title");
        array.put(16974081, "TextAppearance.Holo.Small");
        array.put(16974082, "TextAppearance.Holo.Small.Inverse");
        array.put(16974085, "TextAppearance.Holo.Widget");
        array.put(16974112, "TextAppearance.Holo.Widget.ActionBar.Menu");
        array.put(16974099, "TextAppearance.Holo.Widget.ActionBar.Subtitle");
        array.put(16974109, "TextAppearance.Holo.Widget.ActionBar.Subtitle.Inverse");
        array.put(16974098, "TextAppearance.Holo.Widget.ActionBar.Title");
        array.put(16974108, "TextAppearance.Holo.Widget.ActionBar.Title.Inverse");
        array.put(16974101, "TextAppearance.Holo.Widget.ActionMode.Subtitle");
        array.put(16974111, "TextAppearance.Holo.Widget.ActionMode.Subtitle.Inverse");
        array.put(16974100, "TextAppearance.Holo.Widget.ActionMode.Title");
        array.put(16974110, "TextAppearance.Holo.Widget.ActionMode.Title.Inverse");
        array.put(16974086, "TextAppearance.Holo.Widget.Button");
        array.put(16974091, "TextAppearance.Holo.Widget.DropDownHint");
        array.put(16974092, "TextAppearance.Holo.Widget.DropDownItem");
        array.put(16974094, "TextAppearance.Holo.Widget.EditText");
        array.put(16974087, "TextAppearance.Holo.Widget.IconMenu.Item");
        array.put(16974095, "TextAppearance.Holo.Widget.PopupMenu");
        array.put(16974096, "TextAppearance.Holo.Widget.PopupMenu.Large");
        array.put(16974097, "TextAppearance.Holo.Widget.PopupMenu.Small");
        array.put(16974088, "TextAppearance.Holo.Widget.TabWidget");
        array.put(16974089, "TextAppearance.Holo.Widget.TextView");
        array.put(16974090, "TextAppearance.Holo.Widget.TextView.PopupMenu");
        array.put(16974093, "TextAppearance.Holo.Widget.TextView.SpinnerItem");
        array.put(16974102, "TextAppearance.Holo.WindowTitle");
        array.put(16973887, "TextAppearance.Inverse");
        array.put(16973890, "TextAppearance.Large");
        array.put(16973891, "TextAppearance.Large.Inverse");
        array.put(16974317, "TextAppearance.Material");
        array.put(16974320, "TextAppearance.Material.Body1");
        array.put(16974319, "TextAppearance.Material.Body2");
        array.put(16974318, "TextAppearance.Material.Button");
        array.put(16974321, "TextAppearance.Material.Caption");
        array.put(16974322, "TextAppearance.Material.DialogWindowTitle");
        array.put(16974326, "TextAppearance.Material.Display1");
        array.put(16974325, "TextAppearance.Material.Display2");
        array.put(16974324, "TextAppearance.Material.Display3");
        array.put(16974323, "TextAppearance.Material.Display4");
        array.put(16974327, "TextAppearance.Material.Headline");
        array.put(16974328, "TextAppearance.Material.Inverse");
        array.put(16974329, "TextAppearance.Material.Large");
        array.put(16974330, "TextAppearance.Material.Large.Inverse");
        array.put(16974331, "TextAppearance.Material.Medium");
        array.put(16974332, "TextAppearance.Material.Medium.Inverse");
        array.put(16974333, "TextAppearance.Material.Menu");
        array.put(16974334, "TextAppearance.Material.Notification");
        array.put(16974335, "TextAppearance.Material.Notification.Emphasis");
        array.put(16974336, "TextAppearance.Material.Notification.Info");
        array.put(16974337, "TextAppearance.Material.Notification.Line2");
        array.put(16974338, "TextAppearance.Material.Notification.Time");
        array.put(16974339, "TextAppearance.Material.Notification.Title");
        array.put(16974340, "TextAppearance.Material.SearchResult.Subtitle");
        array.put(16974341, "TextAppearance.Material.SearchResult.Title");
        array.put(16974342, "TextAppearance.Material.Small");
        array.put(16974343, "TextAppearance.Material.Small.Inverse");
        array.put(16974344, "TextAppearance.Material.Subhead");
        array.put(16974345, "TextAppearance.Material.Title");
        array.put(16974347, "TextAppearance.Material.Widget");
        array.put(16974348, "TextAppearance.Material.Widget.ActionBar.Menu");
        array.put(16974349, "TextAppearance.Material.Widget.ActionBar.Subtitle");
        array.put(16974350, "TextAppearance.Material.Widget.ActionBar.Subtitle.Inverse");
        array.put(16974351, "TextAppearance.Material.Widget.ActionBar.Title");
        array.put(16974352, "TextAppearance.Material.Widget.ActionBar.Title.Inverse");
        array.put(16974353, "TextAppearance.Material.Widget.ActionMode.Subtitle");
        array.put(16974354, "TextAppearance.Material.Widget.ActionMode.Subtitle.Inverse");
        array.put(16974355, "TextAppearance.Material.Widget.ActionMode.Title");
        array.put(16974356, "TextAppearance.Material.Widget.ActionMode.Title.Inverse");
        array.put(16974357, "TextAppearance.Material.Widget.Button");
        array.put(16974358, "TextAppearance.Material.Widget.DropDownHint");
        array.put(16974359, "TextAppearance.Material.Widget.DropDownItem");
        array.put(16974360, "TextAppearance.Material.Widget.EditText");
        array.put(16974361, "TextAppearance.Material.Widget.IconMenu.Item");
        array.put(16974362, "TextAppearance.Material.Widget.PopupMenu");
        array.put(16974363, "TextAppearance.Material.Widget.PopupMenu.Large");
        array.put(16974364, "TextAppearance.Material.Widget.PopupMenu.Small");
        array.put(16974365, "TextAppearance.Material.Widget.TabWidget");
        array.put(16974366, "TextAppearance.Material.Widget.TextView");
        array.put(16974367, "TextAppearance.Material.Widget.TextView.PopupMenu");
        array.put(16974368, "TextAppearance.Material.Widget.TextView.SpinnerItem");
        array.put(16974369, "TextAppearance.Material.Widget.Toolbar.Subtitle");
        array.put(16974370, "TextAppearance.Material.Widget.Toolbar.Title");
        array.put(16974346, "TextAppearance.Material.WindowTitle");
        array.put(16973892, "TextAppearance.Medium");
        array.put(16973893, "TextAppearance.Medium.Inverse");
        array.put(16973894, "TextAppearance.Small");
        array.put(16973895, "TextAppearance.Small.Inverse");
        array.put(16973927, "TextAppearance.StatusBar.EventContent");
        array.put(16973928, "TextAppearance.StatusBar.EventContent.Title");
        array.put(16973926, "TextAppearance.StatusBar.Icon");
        array.put(16973925, "TextAppearance.StatusBar.Title");
        array.put(16974104, "TextAppearance.SuggestionHighlight");
        array.put(16973888, "TextAppearance.Theme");
        array.put(16973896, "TextAppearance.Theme.Dialog");
        array.put(16973897, "TextAppearance.Widget");
        array.put(16973898, "TextAppearance.Widget.Button");
        array.put(16973904, "TextAppearance.Widget.DropDownHint");
        array.put(16973905, "TextAppearance.Widget.DropDownItem");
        array.put(16973900, "TextAppearance.Widget.EditText");
        array.put(16973899, "TextAppearance.Widget.IconMenu.Item");
        array.put(16973952, "TextAppearance.Widget.PopupMenu.Large");
        array.put(16973953, "TextAppearance.Widget.PopupMenu.Small");
        array.put(16973901, "TextAppearance.Widget.TabWidget");
        array.put(16973902, "TextAppearance.Widget.TextView");
        array.put(16973903, "TextAppearance.Widget.TextView.PopupMenu");
        array.put(16973906, "TextAppearance.Widget.TextView.SpinnerItem");
        array.put(16973907, "TextAppearance.WindowTitle");
        array.put(16973829, "Theme");
        array.put(16974407, "ThemeOverlay");
        array.put(16974408, "ThemeOverlay.Material");
        array.put(16974409, "ThemeOverlay.Material.ActionBar");
        array.put(16974411, "ThemeOverlay.Material.Dark");
        array.put(16974412, "ThemeOverlay.Material.Dark.ActionBar");
        array.put(16974410, "ThemeOverlay.Material.Light");
        array.put(16973832, "Theme.Black");
        array.put(16973833, "Theme.Black.NoTitleBar");
        array.put(16973834, "Theme.Black.NoTitleBar.Fullscreen");
        array.put(16974120, "Theme.DeviceDefault");
        array.put(16974126, "Theme.DeviceDefault.Dialog");
        array.put(16974134, "Theme.DeviceDefault.DialogWhenLarge");
        array.put(16974135, "Theme.DeviceDefault.DialogWhenLarge.NoActionBar");
        array.put(16974545, "Theme.DeviceDefault.Dialog.Alert");
        array.put(16974127, "Theme.DeviceDefault.Dialog.MinWidth");
        array.put(16974128, "Theme.DeviceDefault.Dialog.NoActionBar");
        array.put(16974129, "Theme.DeviceDefault.Dialog.NoActionBar.MinWidth");
        array.put(16974142, "Theme.DeviceDefault.InputMethod");
        array.put(16974123, "Theme.DeviceDefault.Light");
        array.put(16974143, "Theme.DeviceDefault.Light.DarkActionBar");
        array.put(16974130, "Theme.DeviceDefault.Light.Dialog");
        array.put(16974136, "Theme.DeviceDefault.Light.DialogWhenLarge");
        array.put(16974137, "Theme.DeviceDefault.Light.DialogWhenLarge.NoActionBar");
        array.put(16974546, "Theme.DeviceDefault.Light.Dialog.Alert");
        array.put(16974131, "Theme.DeviceDefault.Light.Dialog.MinWidth");
        array.put(16974132, "Theme.DeviceDefault.Light.Dialog.NoActionBar");
        array.put(16974133, "Theme.DeviceDefault.Light.Dialog.NoActionBar.MinWidth");
        array.put(16974124, "Theme.DeviceDefault.Light.NoActionBar");
        array.put(16974125, "Theme.DeviceDefault.Light.NoActionBar.Fullscreen");
        array.put(16974304, "Theme.DeviceDefault.Light.NoActionBar.Overscan");
        array.put(16974308, "Theme.DeviceDefault.Light.NoActionBar.TranslucentDecor");
        array.put(16974139, "Theme.DeviceDefault.Light.Panel");
        array.put(16974121, "Theme.DeviceDefault.NoActionBar");
        array.put(16974122, "Theme.DeviceDefault.NoActionBar.Fullscreen");
        array.put(16974303, "Theme.DeviceDefault.NoActionBar.Overscan");
        array.put(16974307, "Theme.DeviceDefault.NoActionBar.TranslucentDecor");
        array.put(16974138, "Theme.DeviceDefault.Panel");
        array.put(16974371, "Theme.DeviceDefault.Settings");
        array.put(16974140, "Theme.DeviceDefault.Wallpaper");
        array.put(16974141, "Theme.DeviceDefault.Wallpaper.NoTitleBar");
        array.put(16973835, "Theme.Dialog");
        array.put(16973931, "Theme.Holo");
        array.put(16973935, "Theme.Holo.Dialog");
        array.put(16973943, "Theme.Holo.DialogWhenLarge");
        array.put(16973944, "Theme.Holo.DialogWhenLarge.NoActionBar");
        array.put(16973936, "Theme.Holo.Dialog.MinWidth");
        array.put(16973937, "Theme.Holo.Dialog.NoActionBar");
        array.put(16973938, "Theme.Holo.Dialog.NoActionBar.MinWidth");
        array.put(16973951, "Theme.Holo.InputMethod");
        array.put(16973934, "Theme.Holo.Light");
        array.put(16974105, "Theme.Holo.Light.DarkActionBar");
        array.put(16973939, "Theme.Holo.Light.Dialog");
        array.put(16973945, "Theme.Holo.Light.DialogWhenLarge");
        array.put(16973946, "Theme.Holo.Light.DialogWhenLarge.NoActionBar");
        array.put(16973940, "Theme.Holo.Light.Dialog.MinWidth");
        array.put(16973941, "Theme.Holo.Light.Dialog.NoActionBar");
        array.put(16973942, "Theme.Holo.Light.Dialog.NoActionBar.MinWidth");
        array.put(16974064, "Theme.Holo.Light.NoActionBar");
        array.put(16974065, "Theme.Holo.Light.NoActionBar.Fullscreen");
        array.put(16974302, "Theme.Holo.Light.NoActionBar.Overscan");
        array.put(16974306, "Theme.Holo.Light.NoActionBar.TranslucentDecor");
        array.put(16973948, "Theme.Holo.Light.Panel");
        array.put(16973932, "Theme.Holo.NoActionBar");
        array.put(16973933, "Theme.Holo.NoActionBar.Fullscreen");
        array.put(16974301, "Theme.Holo.NoActionBar.Overscan");
        array.put(16974305, "Theme.Holo.NoActionBar.TranslucentDecor");
        array.put(16973947, "Theme.Holo.Panel");
        array.put(16973949, "Theme.Holo.Wallpaper");
        array.put(16973950, "Theme.Holo.Wallpaper.NoTitleBar");
        array.put(16973908, "Theme.InputMethod");
        array.put(16973836, "Theme.Light");
        array.put(16973837, "Theme.Light.NoTitleBar");
        array.put(16973838, "Theme.Light.NoTitleBar.Fullscreen");
        array.put(16973914, "Theme.Light.Panel");
        array.put(16973922, "Theme.Light.WallpaperSettings");
        array.put(16974372, "Theme.Material");
        array.put(16974373, "Theme.Material.Dialog");
        array.put(16974379, "Theme.Material.DialogWhenLarge");
        array.put(16974380, "Theme.Material.DialogWhenLarge.NoActionBar");
        array.put(16974374, "Theme.Material.Dialog.Alert");
        array.put(16974375, "Theme.Material.Dialog.MinWidth");
        array.put(16974376, "Theme.Material.Dialog.NoActionBar");
        array.put(16974377, "Theme.Material.Dialog.NoActionBar.MinWidth");
        array.put(16974378, "Theme.Material.Dialog.Presentation");
        array.put(16974381, "Theme.Material.InputMethod");
        array.put(16974391, "Theme.Material.Light");
        array.put(16974392, "Theme.Material.Light.DarkActionBar");
        array.put(16974393, "Theme.Material.Light.Dialog");
        array.put(16974399, "Theme.Material.Light.DialogWhenLarge");
        array.put(16974400, "Theme.Material.Light.DialogWhenLarge.NoActionBar");
        array.put(16974394, "Theme.Material.Light.Dialog.Alert");
        array.put(16974395, "Theme.Material.Light.Dialog.MinWidth");
        array.put(16974396, "Theme.Material.Light.Dialog.NoActionBar");
        array.put(16974397, "Theme.Material.Light.Dialog.NoActionBar.MinWidth");
        array.put(16974398, "Theme.Material.Light.Dialog.Presentation");
        array.put(16974401, "Theme.Material.Light.NoActionBar");
        array.put(16974402, "Theme.Material.Light.NoActionBar.Fullscreen");
        array.put(16974403, "Theme.Material.Light.NoActionBar.Overscan");
        array.put(16974404, "Theme.Material.Light.NoActionBar.TranslucentDecor");
        array.put(16974405, "Theme.Material.Light.Panel");
        array.put(16974406, "Theme.Material.Light.Voice");
        array.put(16974382, "Theme.Material.NoActionBar");
        array.put(16974383, "Theme.Material.NoActionBar.Fullscreen");
        array.put(16974384, "Theme.Material.NoActionBar.Overscan");
        array.put(16974385, "Theme.Material.NoActionBar.TranslucentDecor");
        array.put(16974386, "Theme.Material.Panel");
        array.put(16974387, "Theme.Material.Settings");
        array.put(16974388, "Theme.Material.Voice");
        array.put(16974389, "Theme.Material.Wallpaper");
        array.put(16974390, "Theme.Material.Wallpaper.NoTitleBar");
        array.put(16973909, "Theme.NoDisplay");
        array.put(16973830, "Theme.NoTitleBar");
        array.put(16973831, "Theme.NoTitleBar.Fullscreen");
        array.put(16973930, "Theme.NoTitleBar.OverlayActionModes");
        array.put(16973913, "Theme.Panel");
        array.put(16973839, "Theme.Translucent");
        array.put(16973840, "Theme.Translucent.NoTitleBar");
        array.put(16973841, "Theme.Translucent.NoTitleBar.Fullscreen");
        array.put(16973918, "Theme.Wallpaper");
        array.put(16973921, "Theme.WallpaperSettings");
        array.put(16973919, "Theme.Wallpaper.NoTitleBar");
        array.put(16973920, "Theme.Wallpaper.NoTitleBar.Fullscreen");
        array.put(16973929, "Theme.WithActionBar");
        array.put(16973842, "Widget");
        array.put(16973843, "Widget.AbsListView");
        array.put(16973954, "Widget.ActionBar");
        array.put(16974068, "Widget.ActionBar.TabBar");
        array.put(16974067, "Widget.ActionBar.TabText");
        array.put(16974066, "Widget.ActionBar.TabView");
        array.put(16973956, "Widget.ActionButton");
        array.put(16973960, "Widget.ActionButton.CloseMode");
        array.put(16973959, "Widget.ActionButton.Overflow");
        array.put(16973863, "Widget.AutoCompleteTextView");
        array.put(16973844, "Widget.Button");
        array.put(16973845, "Widget.Button.Inset");
        array.put(16973846, "Widget.Button.Small");
        array.put(16973847, "Widget.Button.Toggle");
        array.put(16974059, "Widget.CalendarView");
        array.put(16973848, "Widget.CompoundButton");
        array.put(16973849, "Widget.CompoundButton.CheckBox");
        array.put(16973850, "Widget.CompoundButton.RadioButton");
        array.put(16973851, "Widget.CompoundButton.Star");
        array.put(16974062, "Widget.DatePicker");
        array.put(16974144, "Widget.DeviceDefault");
        array.put(16974187, "Widget.DeviceDefault.ActionBar");
        array.put(16974195, "Widget.DeviceDefault.ActionBar.Solid");
        array.put(16974194, "Widget.DeviceDefault.ActionBar.TabBar");
        array.put(16974193, "Widget.DeviceDefault.ActionBar.TabText");
        array.put(16974192, "Widget.DeviceDefault.ActionBar.TabView");
        array.put(16974182, "Widget.DeviceDefault.ActionButton");
        array.put(16974186, "Widget.DeviceDefault.ActionButton.CloseMode");
        array.put(16974183, "Widget.DeviceDefault.ActionButton.Overflow");
        array.put(16974184, "Widget.DeviceDefault.ActionButton.TextButton");
        array.put(16974185, "Widget.DeviceDefault.ActionMode");
        array.put(16974151, "Widget.DeviceDefault.AutoCompleteTextView");
        array.put(16974145, "Widget.DeviceDefault.Button");
        array.put(16974188, "Widget.DeviceDefault.Button.Borderless");
        array.put(16974149, "Widget.DeviceDefault.Button.Borderless.Small");
        array.put(16974147, "Widget.DeviceDefault.Button.Inset");
        array.put(16974146, "Widget.DeviceDefault.Button.Small");
        array.put(16974148, "Widget.DeviceDefault.Button.Toggle");
        array.put(16974190, "Widget.DeviceDefault.CalendarView");
        array.put(16974299, "Widget.DeviceDefault.CheckedTextView");
        array.put(16974152, "Widget.DeviceDefault.CompoundButton.CheckBox");
        array.put(16974169, "Widget.DeviceDefault.CompoundButton.RadioButton");
        array.put(16974173, "Widget.DeviceDefault.CompoundButton.Star");
        array.put(16974191, "Widget.DeviceDefault.DatePicker");
        array.put(16974177, "Widget.DeviceDefault.DropDownItem");
        array.put(16974178, "Widget.DeviceDefault.DropDownItem.Spinner");
        array.put(16974154, "Widget.DeviceDefault.EditText");
        array.put(16974155, "Widget.DeviceDefault.ExpandableListView");
        array.put(16974313, "Widget.DeviceDefault.FastScroll");
        array.put(16974156, "Widget.DeviceDefault.GridView");
        array.put(16974171, "Widget.DeviceDefault.HorizontalScrollView");
        array.put(16974157, "Widget.DeviceDefault.ImageButton");
        array.put(16974196, "Widget.DeviceDefault.Light");
        array.put(16974243, "Widget.DeviceDefault.Light.ActionBar");
        array.put(16974247, "Widget.DeviceDefault.Light.ActionBar.Solid");
        array.put(16974248, "Widget.DeviceDefault.Light.ActionBar.Solid.Inverse");
        array.put(16974246, "Widget.DeviceDefault.Light.ActionBar.TabBar");
        array.put(16974249, "Widget.DeviceDefault.Light.ActionBar.TabBar.Inverse");
        array.put(16974245, "Widget.DeviceDefault.Light.ActionBar.TabText");
        array.put(16974251, "Widget.DeviceDefault.Light.ActionBar.TabText.Inverse");
        array.put(16974244, "Widget.DeviceDefault.Light.ActionBar.TabView");
        array.put(16974250, "Widget.DeviceDefault.Light.ActionBar.TabView.Inverse");
        array.put(16974239, "Widget.DeviceDefault.Light.ActionButton");
        array.put(16974242, "Widget.DeviceDefault.Light.ActionButton.CloseMode");
        array.put(16974240, "Widget.DeviceDefault.Light.ActionButton.Overflow");
        array.put(16974241, "Widget.DeviceDefault.Light.ActionMode");
        array.put(16974252, "Widget.DeviceDefault.Light.ActionMode.Inverse");
        array.put(16974203, "Widget.DeviceDefault.Light.AutoCompleteTextView");
        array.put(16974197, "Widget.DeviceDefault.Light.Button");
        array.put(16974201, "Widget.DeviceDefault.Light.Button.Borderless.Small");
        array.put(16974199, "Widget.DeviceDefault.Light.Button.Inset");
        array.put(16974198, "Widget.DeviceDefault.Light.Button.Small");
        array.put(16974200, "Widget.DeviceDefault.Light.Button.Toggle");
        array.put(16974238, "Widget.DeviceDefault.Light.CalendarView");
        array.put(16974300, "Widget.DeviceDefault.Light.CheckedTextView");
        array.put(16974204, "Widget.DeviceDefault.Light.CompoundButton.CheckBox");
        array.put(16974224, "Widget.DeviceDefault.Light.CompoundButton.RadioButton");
        array.put(16974228, "Widget.DeviceDefault.Light.CompoundButton.Star");
        array.put(16974232, "Widget.DeviceDefault.Light.DropDownItem");
        array.put(16974233, "Widget.DeviceDefault.Light.DropDownItem.Spinner");
        array.put(16974206, "Widget.DeviceDefault.Light.EditText");
        array.put(16974207, "Widget.DeviceDefault.Light.ExpandableListView");
        array.put(16974315, "Widget.DeviceDefault.Light.FastScroll");
        array.put(16974208, "Widget.DeviceDefault.Light.GridView");
        array.put(16974226, "Widget.DeviceDefault.Light.HorizontalScrollView");
        array.put(16974209, "Widget.DeviceDefault.Light.ImageButton");
        array.put(16974235, "Widget.DeviceDefault.Light.ListPopupWindow");
        array.put(16974210, "Widget.DeviceDefault.Light.ListView");
        array.put(16974205, "Widget.DeviceDefault.Light.ListView.DropDown");
        array.put(16974296, "Widget.DeviceDefault.Light.MediaRouteButton");
        array.put(16974236, "Widget.DeviceDefault.Light.PopupMenu");
        array.put(16974211, "Widget.DeviceDefault.Light.PopupWindow");
        array.put(16974212, "Widget.DeviceDefault.Light.ProgressBar");
        array.put(16974213, "Widget.DeviceDefault.Light.ProgressBar.Horizontal");
        array.put(16974217, "Widget.DeviceDefault.Light.ProgressBar.Inverse");
        array.put(16974216, "Widget.DeviceDefault.Light.ProgressBar.Large");
        array.put(16974219, "Widget.DeviceDefault.Light.ProgressBar.Large.Inverse");
        array.put(16974214, "Widget.DeviceDefault.Light.ProgressBar.Small");
        array.put(16974218, "Widget.DeviceDefault.Light.ProgressBar.Small.Inverse");
        array.put(16974215, "Widget.DeviceDefault.Light.ProgressBar.Small.Title");
        array.put(16974221, "Widget.DeviceDefault.Light.RatingBar");
        array.put(16974222, "Widget.DeviceDefault.Light.RatingBar.Indicator");
        array.put(16974223, "Widget.DeviceDefault.Light.RatingBar.Small");
        array.put(16974225, "Widget.DeviceDefault.Light.ScrollView");
        array.put(16974220, "Widget.DeviceDefault.Light.SeekBar");
        array.put(16974227, "Widget.DeviceDefault.Light.Spinner");
        array.put(16974316, "Widget.DeviceDefault.Light.StackView");
        array.put(16974237, "Widget.DeviceDefault.Light.Tab");
        array.put(16974229, "Widget.DeviceDefault.Light.TabWidget");
        array.put(16974202, "Widget.DeviceDefault.Light.TextView");
        array.put(16974234, "Widget.DeviceDefault.Light.TextView.SpinnerItem");
        array.put(16974230, "Widget.DeviceDefault.Light.WebTextView");
        array.put(16974231, "Widget.DeviceDefault.Light.WebView");
        array.put(16974180, "Widget.DeviceDefault.ListPopupWindow");
        array.put(16974158, "Widget.DeviceDefault.ListView");
        array.put(16974153, "Widget.DeviceDefault.ListView.DropDown");
        array.put(16974295, "Widget.DeviceDefault.MediaRouteButton");
        array.put(16974181, "Widget.DeviceDefault.PopupMenu");
        array.put(16974159, "Widget.DeviceDefault.PopupWindow");
        array.put(16974160, "Widget.DeviceDefault.ProgressBar");
        array.put(16974161, "Widget.DeviceDefault.ProgressBar.Horizontal");
        array.put(16974164, "Widget.DeviceDefault.ProgressBar.Large");
        array.put(16974162, "Widget.DeviceDefault.ProgressBar.Small");
        array.put(16974163, "Widget.DeviceDefault.ProgressBar.Small.Title");
        array.put(16974166, "Widget.DeviceDefault.RatingBar");
        array.put(16974167, "Widget.DeviceDefault.RatingBar.Indicator");
        array.put(16974168, "Widget.DeviceDefault.RatingBar.Small");
        array.put(16974170, "Widget.DeviceDefault.ScrollView");
        array.put(16974165, "Widget.DeviceDefault.SeekBar");
        array.put(16974172, "Widget.DeviceDefault.Spinner");
        array.put(16974314, "Widget.DeviceDefault.StackView");
        array.put(16974189, "Widget.DeviceDefault.Tab");
        array.put(16974174, "Widget.DeviceDefault.TabWidget");
        array.put(16974150, "Widget.DeviceDefault.TextView");
        array.put(16974179, "Widget.DeviceDefault.TextView.SpinnerItem");
        array.put(16974175, "Widget.DeviceDefault.WebTextView");
        array.put(16974176, "Widget.DeviceDefault.WebView");
        array.put(16973867, "Widget.DropDownItem");
        array.put(16973868, "Widget.DropDownItem.Spinner");
        array.put(16973859, "Widget.EditText");
        array.put(16973860, "Widget.ExpandableListView");
        array.put(16974309, "Widget.FastScroll");
        array.put(16973961, "Widget.FragmentBreadCrumbs");
        array.put(16973877, "Widget.Gallery");
        array.put(16973874, "Widget.GridView");
        array.put(16973962, "Widget.Holo");
        array.put(16974004, "Widget.Holo.ActionBar");
        array.put(16974113, "Widget.Holo.ActionBar.Solid");
        array.put(16974071, "Widget.Holo.ActionBar.TabBar");
        array.put(16974070, "Widget.Holo.ActionBar.TabText");
        array.put(16974069, "Widget.Holo.ActionBar.TabView");
        array.put(16973999, "Widget.Holo.ActionButton");
        array.put(16974003, "Widget.Holo.ActionButton.CloseMode");
        array.put(16974000, "Widget.Holo.ActionButton.Overflow");
        array.put(16974001, "Widget.Holo.ActionButton.TextButton");
        array.put(16974002, "Widget.Holo.ActionMode");
        array.put(16973968, "Widget.Holo.AutoCompleteTextView");
        array.put(16973963, "Widget.Holo.Button");
        array.put(16974050, "Widget.Holo.Button.Borderless");
        array.put(16974106, "Widget.Holo.Button.Borderless.Small");
        array.put(16973965, "Widget.Holo.Button.Inset");
        array.put(16973964, "Widget.Holo.Button.Small");
        array.put(16973966, "Widget.Holo.Button.Toggle");
        array.put(16974060, "Widget.Holo.CalendarView");
        array.put(16974297, "Widget.Holo.CheckedTextView");
        array.put(16973969, "Widget.Holo.CompoundButton.CheckBox");
        array.put(16973986, "Widget.Holo.CompoundButton.RadioButton");
        array.put(16973990, "Widget.Holo.CompoundButton.Star");
        array.put(16974063, "Widget.Holo.DatePicker");
        array.put(16973994, "Widget.Holo.DropDownItem");
        array.put(16973995, "Widget.Holo.DropDownItem.Spinner");
        array.put(16973971, "Widget.Holo.EditText");
        array.put(16973972, "Widget.Holo.ExpandableListView");
        array.put(16973973, "Widget.Holo.GridView");
        array.put(16973988, "Widget.Holo.HorizontalScrollView");
        array.put(16973974, "Widget.Holo.ImageButton");
        array.put(16974005, "Widget.Holo.Light");
        array.put(16974049, "Widget.Holo.Light.ActionBar");
        array.put(16974114, "Widget.Holo.Light.ActionBar.Solid");
        array.put(16974115, "Widget.Holo.Light.ActionBar.Solid.Inverse");
        array.put(16974074, "Widget.Holo.Light.ActionBar.TabBar");
        array.put(16974116, "Widget.Holo.Light.ActionBar.TabBar.Inverse");
        array.put(16974073, "Widget.Holo.Light.ActionBar.TabText");
        array.put(16974118, "Widget.Holo.Light.ActionBar.TabText.Inverse");
        array.put(16974072, "Widget.Holo.Light.ActionBar.TabView");
        array.put(16974117, "Widget.Holo.Light.ActionBar.TabView.Inverse");
        array.put(16974045, "Widget.Holo.Light.ActionButton");
        array.put(16974048, "Widget.Holo.Light.ActionButton.CloseMode");
        array.put(16974046, "Widget.Holo.Light.ActionButton.Overflow");
        array.put(16974047, "Widget.Holo.Light.ActionMode");
        array.put(16974119, "Widget.Holo.Light.ActionMode.Inverse");
        array.put(16974011, "Widget.Holo.Light.AutoCompleteTextView");
        array.put(16974006, "Widget.Holo.Light.Button");
        array.put(16974107, "Widget.Holo.Light.Button.Borderless.Small");
        array.put(16974008, "Widget.Holo.Light.Button.Inset");
        array.put(16974007, "Widget.Holo.Light.Button.Small");
        array.put(16974009, "Widget.Holo.Light.Button.Toggle");
        array.put(16974061, "Widget.Holo.Light.CalendarView");
        array.put(16974298, "Widget.Holo.Light.CheckedTextView");
        array.put(16974012, "Widget.Holo.Light.CompoundButton.CheckBox");
        array.put(16974032, "Widget.Holo.Light.CompoundButton.RadioButton");
        array.put(16974036, "Widget.Holo.Light.CompoundButton.Star");
        array.put(16974040, "Widget.Holo.Light.DropDownItem");
        array.put(16974041, "Widget.Holo.Light.DropDownItem.Spinner");
        array.put(16974014, "Widget.Holo.Light.EditText");
        array.put(16974015, "Widget.Holo.Light.ExpandableListView");
        array.put(16974016, "Widget.Holo.Light.GridView");
        array.put(16974034, "Widget.Holo.Light.HorizontalScrollView");
        array.put(16974017, "Widget.Holo.Light.ImageButton");
        array.put(16974043, "Widget.Holo.Light.ListPopupWindow");
        array.put(16974018, "Widget.Holo.Light.ListView");
        array.put(16974013, "Widget.Holo.Light.ListView.DropDown");
        array.put(16974294, "Widget.Holo.Light.MediaRouteButton");
        array.put(16974044, "Widget.Holo.Light.PopupMenu");
        array.put(16974019, "Widget.Holo.Light.PopupWindow");
        array.put(16974020, "Widget.Holo.Light.ProgressBar");
        array.put(16974021, "Widget.Holo.Light.ProgressBar.Horizontal");
        array.put(16974025, "Widget.Holo.Light.ProgressBar.Inverse");
        array.put(16974024, "Widget.Holo.Light.ProgressBar.Large");
        array.put(16974027, "Widget.Holo.Light.ProgressBar.Large.Inverse");
        array.put(16974022, "Widget.Holo.Light.ProgressBar.Small");
        array.put(16974026, "Widget.Holo.Light.ProgressBar.Small.Inverse");
        array.put(16974023, "Widget.Holo.Light.ProgressBar.Small.Title");
        array.put(16974029, "Widget.Holo.Light.RatingBar");
        array.put(16974030, "Widget.Holo.Light.RatingBar.Indicator");
        array.put(16974031, "Widget.Holo.Light.RatingBar.Small");
        array.put(16974033, "Widget.Holo.Light.ScrollView");
        array.put(16974028, "Widget.Holo.Light.SeekBar");
        array.put(16974035, "Widget.Holo.Light.Spinner");
        array.put(16974052, "Widget.Holo.Light.Tab");
        array.put(16974037, "Widget.Holo.Light.TabWidget");
        array.put(16974010, "Widget.Holo.Light.TextView");
        array.put(16974042, "Widget.Holo.Light.TextView.SpinnerItem");
        array.put(16974038, "Widget.Holo.Light.WebTextView");
        array.put(16974039, "Widget.Holo.Light.WebView");
        array.put(16973997, "Widget.Holo.ListPopupWindow");
        array.put(16973975, "Widget.Holo.ListView");
        array.put(16973970, "Widget.Holo.ListView.DropDown");
        array.put(16974293, "Widget.Holo.MediaRouteButton");
        array.put(16973998, "Widget.Holo.PopupMenu");
        array.put(16973976, "Widget.Holo.PopupWindow");
        array.put(16973977, "Widget.Holo.ProgressBar");
        array.put(16973978, "Widget.Holo.ProgressBar.Horizontal");
        array.put(16973981, "Widget.Holo.ProgressBar.Large");
        array.put(16973979, "Widget.Holo.ProgressBar.Small");
        array.put(16973980, "Widget.Holo.ProgressBar.Small.Title");
        array.put(16973983, "Widget.Holo.RatingBar");
        array.put(16973984, "Widget.Holo.RatingBar.Indicator");
        array.put(16973985, "Widget.Holo.RatingBar.Small");
        array.put(16973987, "Widget.Holo.ScrollView");
        array.put(16973982, "Widget.Holo.SeekBar");
        array.put(16973989, "Widget.Holo.Spinner");
        array.put(16974051, "Widget.Holo.Tab");
        array.put(16973991, "Widget.Holo.TabWidget");
        array.put(16973967, "Widget.Holo.TextView");
        array.put(16973996, "Widget.Holo.TextView.SpinnerItem");
        array.put(16973992, "Widget.Holo.WebTextView");
        array.put(16973993, "Widget.Holo.WebView");
        array.put(16973862, "Widget.ImageButton");
        array.put(16973861, "Widget.ImageWell");
        array.put(16973911, "Widget.KeyboardView");
        array.put(16973957, "Widget.ListPopupWindow");
        array.put(16973870, "Widget.ListView");
        array.put(16973872, "Widget.ListView.DropDown");
        array.put(16973873, "Widget.ListView.Menu");
        array.put(16973871, "Widget.ListView.White");
        array.put(16974413, "Widget.Material");
        array.put(16974414, "Widget.Material.ActionBar");
        array.put(16974415, "Widget.Material.ActionBar.Solid");
        array.put(16974416, "Widget.Material.ActionBar.TabBar");
        array.put(16974417, "Widget.Material.ActionBar.TabText");
        array.put(16974418, "Widget.Material.ActionBar.TabView");
        array.put(16974419, "Widget.Material.ActionButton");
        array.put(16974420, "Widget.Material.ActionButton.CloseMode");
        array.put(16974421, "Widget.Material.ActionButton.Overflow");
        array.put(16974422, "Widget.Material.ActionMode");
        array.put(16974423, "Widget.Material.AutoCompleteTextView");
        array.put(16974424, "Widget.Material.Button");
        array.put(16974431, "Widget.Material.ButtonBar");
        array.put(16974432, "Widget.Material.ButtonBar.AlertDialog");
        array.put(16974425, "Widget.Material.Button.Borderless");
        array.put(16974426, "Widget.Material.Button.Borderless.Colored");
        array.put(16974427, "Widget.Material.Button.Borderless.Small");
        array.put(16974428, "Widget.Material.Button.Inset");
        array.put(16974429, "Widget.Material.Button.Small");
        array.put(16974430, "Widget.Material.Button.Toggle");
        array.put(16974433, "Widget.Material.CalendarView");
        array.put(16974434, "Widget.Material.CheckedTextView");
        array.put(16974435, "Widget.Material.CompoundButton.CheckBox");
        array.put(16974436, "Widget.Material.CompoundButton.RadioButton");
        array.put(16974437, "Widget.Material.CompoundButton.Star");
        array.put(16974438, "Widget.Material.DatePicker");
        array.put(16974439, "Widget.Material.DropDownItem");
        array.put(16974440, "Widget.Material.DropDownItem.Spinner");
        array.put(16974441, "Widget.Material.EditText");
        array.put(16974442, "Widget.Material.ExpandableListView");
        array.put(16974443, "Widget.Material.FastScroll");
        array.put(16974444, "Widget.Material.GridView");
        array.put(16974445, "Widget.Material.HorizontalScrollView");
        array.put(16974446, "Widget.Material.ImageButton");
        array.put(16974478, "Widget.Material.Light");
        array.put(16974479, "Widget.Material.Light.ActionBar");
        array.put(16974480, "Widget.Material.Light.ActionBar.Solid");
        array.put(16974481, "Widget.Material.Light.ActionBar.TabBar");
        array.put(16974482, "Widget.Material.Light.ActionBar.TabText");
        array.put(16974483, "Widget.Material.Light.ActionBar.TabView");
        array.put(16974484, "Widget.Material.Light.ActionButton");
        array.put(16974485, "Widget.Material.Light.ActionButton.CloseMode");
        array.put(16974486, "Widget.Material.Light.ActionButton.Overflow");
        array.put(16974487, "Widget.Material.Light.ActionMode");
        array.put(16974488, "Widget.Material.Light.AutoCompleteTextView");
        array.put(16974489, "Widget.Material.Light.Button");
        array.put(16974496, "Widget.Material.Light.ButtonBar");
        array.put(16974497, "Widget.Material.Light.ButtonBar.AlertDialog");
        array.put(16974490, "Widget.Material.Light.Button.Borderless");
        array.put(16974491, "Widget.Material.Light.Button.Borderless.Colored");
        array.put(16974492, "Widget.Material.Light.Button.Borderless.Small");
        array.put(16974493, "Widget.Material.Light.Button.Inset");
        array.put(16974494, "Widget.Material.Light.Button.Small");
        array.put(16974495, "Widget.Material.Light.Button.Toggle");
        array.put(16974498, "Widget.Material.Light.CalendarView");
        array.put(16974499, "Widget.Material.Light.CheckedTextView");
        array.put(16974500, "Widget.Material.Light.CompoundButton.CheckBox");
        array.put(16974501, "Widget.Material.Light.CompoundButton.RadioButton");
        array.put(16974502, "Widget.Material.Light.CompoundButton.Star");
        array.put(16974503, "Widget.Material.Light.DatePicker");
        array.put(16974504, "Widget.Material.Light.DropDownItem");
        array.put(16974505, "Widget.Material.Light.DropDownItem.Spinner");
        array.put(16974506, "Widget.Material.Light.EditText");
        array.put(16974507, "Widget.Material.Light.ExpandableListView");
        array.put(16974508, "Widget.Material.Light.FastScroll");
        array.put(16974509, "Widget.Material.Light.GridView");
        array.put(16974510, "Widget.Material.Light.HorizontalScrollView");
        array.put(16974511, "Widget.Material.Light.ImageButton");
        array.put(16974512, "Widget.Material.Light.ListPopupWindow");
        array.put(16974513, "Widget.Material.Light.ListView");
        array.put(16974514, "Widget.Material.Light.ListView.DropDown");
        array.put(16974515, "Widget.Material.Light.MediaRouteButton");
        array.put(16974516, "Widget.Material.Light.PopupMenu");
        array.put(16974517, "Widget.Material.Light.PopupMenu.Overflow");
        array.put(16974518, "Widget.Material.Light.PopupWindow");
        array.put(16974519, "Widget.Material.Light.ProgressBar");
        array.put(16974520, "Widget.Material.Light.ProgressBar.Horizontal");
        array.put(16974521, "Widget.Material.Light.ProgressBar.Inverse");
        array.put(16974522, "Widget.Material.Light.ProgressBar.Large");
        array.put(16974523, "Widget.Material.Light.ProgressBar.Large.Inverse");
        array.put(16974524, "Widget.Material.Light.ProgressBar.Small");
        array.put(16974525, "Widget.Material.Light.ProgressBar.Small.Inverse");
        array.put(16974526, "Widget.Material.Light.ProgressBar.Small.Title");
        array.put(16974527, "Widget.Material.Light.RatingBar");
        array.put(16974528, "Widget.Material.Light.RatingBar.Indicator");
        array.put(16974529, "Widget.Material.Light.RatingBar.Small");
        array.put(16974530, "Widget.Material.Light.ScrollView");
        array.put(16974531, "Widget.Material.Light.SearchView");
        array.put(16974532, "Widget.Material.Light.SeekBar");
        array.put(16974533, "Widget.Material.Light.SegmentedButton");
        array.put(16974535, "Widget.Material.Light.Spinner");
        array.put(16974536, "Widget.Material.Light.Spinner.Underlined");
        array.put(16974534, "Widget.Material.Light.StackView");
        array.put(16974537, "Widget.Material.Light.Tab");
        array.put(16974538, "Widget.Material.Light.TabWidget");
        array.put(16974539, "Widget.Material.Light.TextView");
        array.put(16974540, "Widget.Material.Light.TextView.SpinnerItem");
        array.put(16974541, "Widget.Material.Light.TimePicker");
        array.put(16974542, "Widget.Material.Light.WebTextView");
        array.put(16974543, "Widget.Material.Light.WebView");
        array.put(16974447, "Widget.Material.ListPopupWindow");
        array.put(16974448, "Widget.Material.ListView");
        array.put(16974449, "Widget.Material.ListView.DropDown");
        array.put(16974450, "Widget.Material.MediaRouteButton");
        array.put(16974451, "Widget.Material.PopupMenu");
        array.put(16974452, "Widget.Material.PopupMenu.Overflow");
        array.put(16974453, "Widget.Material.PopupWindow");
        array.put(16974454, "Widget.Material.ProgressBar");
        array.put(16974455, "Widget.Material.ProgressBar.Horizontal");
        array.put(16974456, "Widget.Material.ProgressBar.Large");
        array.put(16974457, "Widget.Material.ProgressBar.Small");
        array.put(16974458, "Widget.Material.ProgressBar.Small.Title");
        array.put(16974459, "Widget.Material.RatingBar");
        array.put(16974460, "Widget.Material.RatingBar.Indicator");
        array.put(16974461, "Widget.Material.RatingBar.Small");
        array.put(16974462, "Widget.Material.ScrollView");
        array.put(16974463, "Widget.Material.SearchView");
        array.put(16974464, "Widget.Material.SeekBar");
        array.put(16974465, "Widget.Material.SegmentedButton");
        array.put(16974467, "Widget.Material.Spinner");
        array.put(16974468, "Widget.Material.Spinner.Underlined");
        array.put(16974466, "Widget.Material.StackView");
        array.put(16974469, "Widget.Material.Tab");
        array.put(16974470, "Widget.Material.TabWidget");
        array.put(16974471, "Widget.Material.TextView");
        array.put(16974472, "Widget.Material.TextView.SpinnerItem");
        array.put(16974473, "Widget.Material.TimePicker");
        array.put(16974474, "Widget.Material.Toolbar");
        array.put(16974475, "Widget.Material.Toolbar.Button.Navigation");
        array.put(16974476, "Widget.Material.WebTextView");
        array.put(16974477, "Widget.Material.WebView");
        array.put(16973958, "Widget.PopupMenu");
        array.put(16973878, "Widget.PopupWindow");
        array.put(16973852, "Widget.ProgressBar");
        array.put(16973855, "Widget.ProgressBar.Horizontal");
        array.put(16973915, "Widget.ProgressBar.Inverse");
        array.put(16973853, "Widget.ProgressBar.Large");
        array.put(16973916, "Widget.ProgressBar.Large.Inverse");
        array.put(16973854, "Widget.ProgressBar.Small");
        array.put(16973917, "Widget.ProgressBar.Small.Inverse");
        array.put(16973857, "Widget.RatingBar");
        array.put(16973869, "Widget.ScrollView");
        array.put(16973856, "Widget.SeekBar");
        array.put(16973864, "Widget.Spinner");
        array.put(16973955, "Widget.Spinner.DropDown");
        array.put(16974310, "Widget.StackView");
        array.put(16973876, "Widget.TabWidget");
        array.put(16973858, "Widget.TextView");
        array.put(16973865, "Widget.TextView.PopupMenu");
        array.put(16973866, "Widget.TextView.SpinnerItem");
        array.put(16974311, "Widget.Toolbar");
        array.put(16974312, "Widget.Toolbar.Button.Navigation");
        array.put(16973875, "Widget.WebView");
        return array;
    }
}
